@@ -246,10 +246,10 @@ void ProjectClip::setCurrent(bool current, bool notify)
     }
 }
 
-QDomElement ProjectClip::toXml(QDomDocument& document)
+QDomElement ProjectClip::toXml(QDomDocument& document, bool includeMeta)
 {
     if (m_controller) {
-        m_controller->getProducerXML(document);
+        m_controller->getProducerXML(document, includeMeta);
         return document.documentElement().firstChildElement("producer");
     }
     return QDomElement();
@@ -272,6 +272,7 @@ void ProjectClip::setThumbnail(QImage img)
         p.drawText(r, Qt::AlignCenter, i18nc("The first letter of Proxy, used as abbreviation", "P"));
     }
     m_thumbnail = QIcon(thumb);
+    emit thumbUpdated(img);
     bin()->emitItemUpdated(this);
 }
 
@@ -289,8 +290,6 @@ bool ProjectClip::setProducer(ClipController *controller, bool replaceProducer)
     bool isNewProducer = true;
     if (m_controller) {
         // Replace clip for this controller
-        //m_controller->updateProducer(m_id, &(controller->originalProducer()));
-       //delete controller;
         resetProducerProperty("kdenlive:file_hash");
         isNewProducer = false;
     }
