@@ -117,7 +117,7 @@ public:
     
     virtual bool rename(const QString &name, int column);
 
-    virtual QDomElement toXml(QDomDocument &document);
+    virtual QDomElement toXml(QDomDocument &document, bool includeMeta = false);
     
     QVariant data(DataType type) const;
 
@@ -239,6 +239,7 @@ signals:
     void refreshAnalysisPanel();
     void refreshClipDisplay();
     void thumbReady(int, QImage);
+    void thumbUpdated(QImage);
     void updateJobStatus(int jobType, int status, int progress = 0, const QString &statusMessage = QString());
 };
 
