@@ -27,6 +27,10 @@ Core *Core::m_self = NULL;
 
 Core::Core(MainWindow *mainWindow) :
     m_mainWindow(mainWindow)
+    , m_projectManager(NULL)
+    , m_monitorManager(NULL)
+    , m_binController(NULL)
+    , m_binWidget(NULL)
 {
     connect(qApp, SIGNAL(aboutToQuit()), this, SLOT(deleteLater()));
 }
@@ -41,22 +45,21 @@ Core::~Core()
     m_self = 0;
 }
 
-void Core::initialize(MainWindow* mainWindow)
+void Core::build(MainWindow* mainWindow)
 {
     m_self = new Core(mainWindow);
-    m_self->init();
+    m_self->initLocale();
 }
 
-void Core::init()
+void Core::initialize()
 {
-    initLocale();
     m_projectManager = new ProjectManager(this);
     m_binWidget = new Bin();
     m_binController = new BinController();
     connect(m_binWidget, SIGNAL(storeFolder(QString,QString,QString,QString)), m_binController, SLOT(slotStoreFolder(QString,QString,QString,QString)));
     connect(m_binController, SIGNAL(loadFolders(QMap<QString,QString>)), m_binWidget, SLOT(slotLoadFolders(QMap<QString,QString>)));
     connect(m_binController, SIGNAL(requestAudioThumb(QString)), m_binWidget, SLOT(slotCreateAudioThumb(QString)));
-    connect(m_binController, SIGNAL(abortAudioThumb(QString)), m_binWidget, SLOT(slotAbortAudioThumb(QString)));
+    connect(m_binController, SIGNAL(abortAudioThumbs()), m_binWidget, SLOT(abortAudioThumbs()));
     connect(m_binController, SIGNAL(loadThumb(QString,QImage,bool)), m_binWidget, SLOT(slotThumbnailReady(QString,QImage,bool)));
     m_monitorManager = new MonitorManager(this);
     emit coreIsReady();
