@@ -56,6 +56,7 @@ const QString stopmotionMonitor("stopmotionMonitor");
 
 enum OperationType {
     None = 0,
+    WaitingForConfirm,
     MoveOperation,
     ResizeStart,
     ResizeEnd,
@@ -69,7 +70,8 @@ enum OperationType {
     Spacer,
     RubberSelection,
     ScrollTimeline,
-    ZoomTimeline
+    ZoomTimeline,
+    ContextMenu
 };
 
 namespace PlaylistState {
@@ -116,6 +118,13 @@ enum ProjectTool {
     SpacerTool = 2
 };
 
+enum MonitorSceneType {
+    MonitorSceneNone = 0,
+    MonitorSceneGeometry,
+    MonitorSceneCorners,
+    MonitorSceneRoto
+};
+
 enum TransitionType {
     /** TRANSITIONTYPE: between 0-99: video trans, 100-199: video+audio trans, 200-299: audio trans */
     LumaTransition = 0,
@@ -156,6 +165,7 @@ public:
     bool isMute;
     bool isBlind;
     bool isLocked;
+    bool composite;
     int duration;
     EffectsList effectsList;
     TrackInfo() :
@@ -163,6 +173,7 @@ public:
         isMute(0),
         isBlind(0),
         isLocked(0),
+        composite(0),
         duration(0),
         effectsList(true) {}
 };
@@ -176,7 +187,6 @@ struct ProfileInfo {
 struct requestClipInfo {
     QDomElement xml;
     QString clipId;
-    int binIndex;
     int imageHeight;
     bool replaceProducer;
 
@@ -200,6 +210,7 @@ public:
     GenTime cropStart;
     /** cropDuration is the duration of the clip */
     GenTime cropDuration;
+    /** Track number */
     int track;
     ItemInfo() : track(0) {}
 };
