@@ -21,6 +21,7 @@
 #include "profilesdialog.h"
 #include "encodingprofilesdialog.h"
 #include "utils/KoIconUtils.h"
+#include "dialogs/profilesdialog.h"
 #include "kdenlivesettings.h"
 #include "renderer.h"
 
@@ -61,7 +62,8 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
     KdenliveSettings::setV4l_format(0);
     QWidget *p1 = new QWidget;
     m_configMisc.setupUi(p1);
-    m_page1 = addPage(p1, i18n("Misc"), "configure");
+    m_page1 = addPage(p1, i18n("Misc"));
+    m_page1->setIcon(KoIconUtils::themedIcon(QStringLiteral("configure")));
 
     // Hide avformat-novalidate trick, causes crash (bug #2205 and #2206)
     m_configMisc.kcfg_projectloading_avformatnovalidate->setVisible(false);
@@ -70,7 +72,9 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
 
     QWidget *p8 = new QWidget;
     m_configProject.setupUi(p8);
-    m_page8 = addPage(p8, i18n("Project Defaults"), "document-new");
+
+    m_page8 = addPage(p8, i18n("Project Defaults"));
+    m_page8->setIcon(KoIconUtils::themedIcon(QStringLiteral("project-defaults")));
     connect(m_configProject.kcfg_generateproxy, SIGNAL(toggled(bool)), m_configProject.kcfg_proxyminsize, SLOT(setEnabled(bool)));
     m_configProject.kcfg_proxyminsize->setEnabled(KdenliveSettings::generateproxy());
     connect(m_configProject.kcfg_generateimageproxy, SIGNAL(toggled(bool)), m_configProject.kcfg_proxyimageminsize, SLOT(setEnabled(bool)));
@@ -78,7 +82,8 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
 
     QWidget *p3 = new QWidget;
     m_configTimeline.setupUi(p3);
-    m_page3 = addPage(p3, i18n("Timeline"), "video-display");
+    m_page3 = addPage(p3, i18n("Timeline"));
+    m_page3->setIcon(KoIconUtils::themedIcon(QStringLiteral("video-display")));
 
     QWidget *p2 = new QWidget;
     m_configEnv.setupUi(p2);
@@ -98,7 +103,8 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
     m_configEnv.capturefolderurl->lineEdit()->setObjectName("kcfg_capturefolder");
     m_configEnv.capturefolderurl->setEnabled(!KdenliveSettings::capturetoprojectfolder());
     connect(m_configEnv.kcfg_capturetoprojectfolder, SIGNAL(clicked()), this, SLOT(slotEnableCaptureFolder()));
-    m_page2 = addPage(p2, i18n("Environment"), "application-x-executable-script");
+    m_page2 = addPage(p2, i18n("Environment"));
+    m_page2->setIcon(KoIconUtils::themedIcon(QStringLiteral("application-x-executable-script")));
 
     QWidget *p4 = new QWidget;
     m_configCapture.setupUi(p4);
@@ -123,7 +129,8 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
     slotUpdatev4lDevice();
 #endif
 
-    m_page4 = addPage(p4, i18n("Capture"), "media-record");
+    m_page4 = addPage(p4, i18n("Capture"));
+    m_page4->setIcon(KoIconUtils::themedIcon(QStringLiteral("media-record")));
     m_configCapture.tabWidget->setCurrentIndex(KdenliveSettings::defaultcapture());
 #ifdef Q_WS_MAC
     m_configCapture.tabWidget->setEnabled(false);
@@ -167,7 +174,8 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
     m_configShuttle.kcfg_enableshuttle->hide();
     m_configShuttle.kcfg_enableshuttle->setDisabled(true);
 #endif /* USE_JOGSHUTTLE */
-    m_page5 = addPage(p5, i18n("JogShuttle"), "input-mouse");
+    m_page5 = addPage(p5, i18n("JogShuttle"));
+    m_page5->setIcon(KoIconUtils::themedIcon(QStringLiteral("jog-dial")));
 
     QWidget *p6 = new QWidget;
     m_configSdl.setupUi(p6);
@@ -177,11 +185,14 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
     //m_configSdl.kcfg_openglmonitors->setHidden(true);
 
 
-    m_page6 = addPage(p6, i18n("Playback"), "media-playback-start");
+    m_page6 = addPage(p6, i18n("Playback"));
+    m_page6->setIcon(KoIconUtils::themedIcon(QStringLiteral("media-playback-start")));
 
     QWidget *p7 = new QWidget;
     m_configTranscode.setupUi(p7);
-    m_page7 = addPage(p7, i18n("Transcode"), "edit-copy");
+    m_page7 = addPage(p7, i18n("Transcode"));
+    m_page7->setIcon(KoIconUtils::themedIcon(QStringLiteral("edit-copy")));
+
     connect(m_configTranscode.button_add, SIGNAL(clicked()), this, SLOT(slotAddTranscode()));
     connect(m_configTranscode.button_delete, SIGNAL(clicked()), this, SLOT(slotDeleteTranscode()));
     connect(m_configTranscode.profiles_list, SIGNAL(itemChanged(QListWidgetItem*)), this, SLOT(slotDialogModified()));
@@ -254,9 +265,17 @@ KdenliveSettingsDialog::KdenliveSettingsDialog(const QMap<QString, QString>& map
     connect(m_configCapture.kcfg_grab_profile, SIGNAL(currentIndexChanged(int)), this, SLOT(slotUpdateGrabProfile()));
     connect(m_configCapture.grab_showprofileinfo, SIGNAL(clicked(bool)), m_configCapture.grab_parameters, SLOT(setVisible(bool)));
 
+    // Project profile management
+    m_configProject.manage_profiles->setIcon(KoIconUtils::themedIcon("configure"));
+    m_configProject.manage_profiles->setToolTip(i18n("Manage Project Profiles"));
+    connect(m_configProject.manage_profiles, SIGNAL(clicked(bool)), this, SLOT(slotEditProfiles()));
+
     // proxy profile stuff
-    m_configProject.proxy_showprofileinfo->setIcon(KoIconUtils::themedIcon("help-about"));
-    m_configProject.proxy_manageprofile->setIcon(KoIconUtils::themedIcon("configure"));
+    m_configProject.proxy_showprofileinfo->setIcon(KoIconUtils::themedIcon(QStringLiteral("help-about")));
+    m_configProject.proxy_showprofileinfo->setToolTip(i18n("Show default profile parameters"));
+    m_configProject.proxy_manageprofile->setIcon(KoIconUtils::themedIcon(QStringLiteral("configure")));
+    m_configProject.proxy_manageprofile->setToolTip(i18n("Manage proxy profiles"));
+    m_configProject.kcfg_proxy_profile->setToolTip(i18n("Select default proxy profile"));
     m_configProject.proxyparams->setVisible(false);
     m_configProject.proxyparams->setMaximumHeight(QFontMetrics(font()).lineSpacing() * 4);
     m_configProject.proxyparams->setPlainText(KdenliveSettings::proxyparams());
@@ -1228,6 +1247,14 @@ void KdenliveSettingsDialog::slotReloadBlackMagic()
     m_configSdl.kcfg_external_display->setEnabled(KdenliveSettings::decklink_device_found());
 }
 
+void KdenliveSettingsDialog::slotEditProfiles()
+{
+    ProfilesDialog *w = new ProfilesDialog;
+    w->exec();
+    checkProfile();
+    delete w;
+}
+
 void KdenliveSettingsDialog::slotReloadShuttleDevices()
 {
 #ifdef USE_JOGSHUTTLE
