@@ -86,7 +86,7 @@ DocClipBase::DocClipBase(ClipManager *clipManager, QDomElement xml, const QStrin
     }
 
     QUrl url = QUrl::fromLocalFile(xml.attribute("resource"));
-    if (!m_properties.contains("file_hash") && url.isValid()) getFileHash(url.toLocalFile());
+    if (!m_properties.contains("kdenlive:file_hash") && url.isValid()) getFileHash(url.toLocalFile());
 
     if (xml.hasAttribute("duration")) {
         setDuration(GenTime(xml.attribute("duration").toInt(), KdenliveSettings::project_fps()));
@@ -98,7 +98,7 @@ DocClipBase::DocClipBase(ClipManager *clipManager, QDomElement xml, const QStrin
 
     if (!m_properties.contains("name")) m_properties.insert("name", url.fileName());
 
-    m_thumbProd = new KThumb(clipManager, url, m_id, m_properties.value("file_hash"));
+    m_thumbProd = new KThumb(clipManager, url, m_id, m_properties.value("kdenlive:file_hash"));
     
     // Setup timer to trigger audio thumbs creation
     m_audioTimer.setSingleShot(true);
@@ -134,13 +134,6 @@ QPoint DocClipBase::zone() const
     return zone;
 }
 
-
-bool DocClipBase::hasAudioThumb() const
-{
-    if (m_clipType == Audio || m_clipType == AV || m_clipType == Playlist) return true;
-    return false;
-}
-
 KThumb *DocClipBase::thumbProducer()
 {
     return m_thumbProd;
@@ -180,11 +173,6 @@ QUrl DocClipBase::fileURL() const
     return QUrl();
 }
 
-void DocClipBase::setClipThumbFrame(const uint &ix)
-{
-    m_properties.insert("thumbnail", QString::number((int) ix));
-}
-
 uint DocClipBase::getClipThumbFrame() const
 {
     return (uint) m_properties.value("thumbnail").toInt();
@@ -374,20 +362,6 @@ void DocClipBase::addSnapMarker(const CommentedTime &marker)
     }
 }
 
-void DocClipBase::editSnapMarker(const GenTime & time, const QString &comment)
-{
-    QList < CommentedTime >::Iterator it;
-    for (it = m_snapMarkers.begin(); it != m_snapMarkers.end(); ++it) {
-        if ((*it).time() == time)
-            break;
-    }
-    if (it != m_snapMarkers.end()) {
-        (*it).setComment(comment);
-    } else {
-        qCritical() << "trying to edit Snap Marker that does not already exists";
-    }
-}
-
 QString DocClipBase::deleteSnapMarker(const GenTime & time)
 {
     QString result = i18n("Marker");
@@ -407,30 +381,6 @@ QString DocClipBase::deleteSnapMarker(const GenTime & time)
 }
 
 
-GenTime DocClipBase::findPreviousSnapMarker(const GenTime & currTime)
-{
-    int it;
-    for (it = 0; it < m_snapMarkers.count(); ++it) {
-        if (m_snapMarkers.at(it).time() >= currTime)
-            break;
-    }
-    if (it == 0) return GenTime();
-    else if (it == m_snapMarkers.count() - 1 && m_snapMarkers.at(it).time() < currTime)
-        return m_snapMarkers.at(it).time();
-    else return m_snapMarkers.at(it - 1).time();
-}
-
-GenTime DocClipBase::findNextSnapMarker(const GenTime & currTime)
-{
-    int it;
-    for (it = 0; it < m_snapMarkers.count(); ++it) {
-        if (m_snapMarkers.at(it).time() > currTime)
-            break;
-    }
-    if (it < m_snapMarkers.count() && m_snapMarkers.at(it).time() > currTime) return m_snapMarkers.at(it).time();
-    return duration();
-}
-
 QString DocClipBase::markerComment(const GenTime &t) const
 {
     QList < CommentedTime >::ConstIterator itt = m_snapMarkers.begin();
@@ -491,29 +441,6 @@ void DocClipBase::deleteProducers()
     m_audioTrackProducers.clear();
 }
 
-void DocClipBase::cleanupProducers()
-{
-    /*
-    int ct = 0;
-    //qDebug()<<"----------------------------------------------------------------------------------";
-    for (int i = 0; i < m_toDeleteProducers.count(); ++i) {
-        if (m_toDeleteProducers.at(i) != NULL) {
-            Mlt::Properties props(m_toDeleteProducers.at(i)->get_properties());
-            if (props.ref_count() > 2) {
-                //qDebug()<<"PRODUCER: "<<i<<", COUNTS: "<<props.ref_count();
-                //exit(1);
-            }
-            ct++;
-        }
-    }*/
-
-    if (!isClean()) {
-        qDeleteAll(m_toDeleteProducers);
-        m_toDeleteProducers.clear();
-        m_replaceMutex.unlock();
-    }
-}
-
 bool DocClipBase::isClean() const
 {
     return m_toDeleteProducers.isEmpty();
@@ -524,8 +451,11 @@ void DocClipBase::setValid()
     m_placeHolder = false;
 }
 
-void DocClipBase::setProducer(Mlt::Producer *producer, bool reset, bool readPropertiesFromProducer)
+void DocClipBase::setProducer(Mlt::Producer &producer, bool reset, bool readPropertiesFromProducer)
 {
+    setDuration(GenTime(producer.get_length(), KdenliveSettings::project_fps()));
+    return;
+    /*
     if (producer == NULL) return;
     if (reset) {
         QMutexLocker locker(&m_producerMutex);
@@ -603,6 +533,7 @@ void DocClipBase::setProducer(Mlt::Producer *producer, bool reset, bool readProp
     }
     if (updated && readPropertiesFromProducer && (m_clipType != Color && m_clipType != Image && m_clipType != Text))
         setDuration(GenTime(producer->get_length(), KdenliveSettings::project_fps()));
+    */
 }
 
 static double getPixelAspect(QMap<QString, QString>& props) {
@@ -698,52 +629,10 @@ Mlt::Producer *DocClipBase::videoProducer(int track)
     return m_videoTrackProducers.at(track);
 }
 
-Mlt::Producer *DocClipBase::getCloneProducer()
-{
-    Mlt::Producer *source = NULL;
-    Mlt::Producer *prod = NULL;
-    if (m_clipType != Audio && m_clipType != AV && m_clipType != Playlist) {
-        source = getProducer();
-        if (!source) return NULL;
-    }
-    if (m_clipType == Color) {
-        prod = new Mlt::Producer(*(source->profile()), 0, QString("colour:" + QString(source->get("resource"))).toUtf8().constData());
-    } else if (m_clipType == Text) {
-        prod = new Mlt::Producer(*(source->profile()), 0, QString("kdenlivetitle:" + QString(source->get("resource"))).toUtf8().constData());
-        if (prod && prod->is_valid() && m_properties.contains("xmldata"))
-            prod->set("xmldata", m_properties.value("xmldata").toUtf8().constData());
-    }
-    if (!prod) {
-        if (!source) {
-            QMutexLocker locker(&m_producerMutex);
-            for (int i = 0; i < m_baseTrackProducers.count(); ++i) {
-                if (m_baseTrackProducers.at(i) != NULL) {
-                    source = m_baseTrackProducers.at(i);
-                    break;
-                }
-            }
-            if (!source) return NULL;
-        }
-        prod = cloneProducer(source);
-    }
-    if (prod) {
-        adjustProducerProperties(prod, getId() + '_', false, false);
-        if (!m_properties.contains("proxy_out")) {
-            // Adjust length in case...
-            if (m_properties.contains("duration")) prod->set("length", m_properties.value("duration").toInt());
-            if (m_properties.contains("out"))prod->set("out", m_properties.value("out").toInt());
-        }
-        if (m_clipType == Audio) {
-            prod->set("_audioclip", 1);
-        }
-    }
-    return prod;
-}
-
-
 Mlt::Producer *DocClipBase::getProducer(int track)
 {
     QMutexLocker locker(&m_producerMutex);
+
     if (track == -1 || (m_clipType != Audio && m_clipType != AV && m_clipType != Playlist)) {
         if (m_baseTrackProducers.count() == 0) {
             return NULL;
@@ -1080,7 +969,7 @@ void DocClipBase::getFileHash(const QString &url)
             fileData = file.readAll();
         file.close();
         fileHash = QCryptographicHash::hash(fileData, QCryptographicHash::Md5);
-        m_properties.insert("file_hash", QString(fileHash.toHex()));
+        m_properties.insert("kdenlive:file_hash", QString(fileHash.toHex()));
     }
 }
 
@@ -1098,7 +987,7 @@ QString DocClipBase::getClipHash() const
     else if (m_clipType == Color) hash = QCryptographicHash::hash(m_properties.value("colour").toLatin1().data(), QCryptographicHash::Md5).toHex();
     else if (m_clipType == Text) hash = QCryptographicHash::hash(QString("title" + getId() + m_properties.value("xmldata")).toUtf8().data(), QCryptographicHash::Md5).toHex();
     else {
-        if (m_properties.contains("file_hash")) hash = m_properties.value("file_hash");
+        if (m_properties.contains("kdenlive:file_hash")) hash = m_properties.value("kdenlive:file_hash");
         if (hash.isEmpty()) hash = getHash(fileURL().path());
         
     }
@@ -1138,7 +1027,7 @@ void DocClipBase::setProperty(const QString &key, const QString &value)
     m_properties.insert(key, value);
     if (key == "resource") {
         getFileHash(value);
-        if (m_thumbProd) m_thumbProd->updateClipUrl(QUrl::fromLocalFile(value), m_properties.value("file_hash"));
+        if (m_thumbProd) m_thumbProd->updateClipUrl(QUrl::fromLocalFile(value), m_properties.value("kdenlive:file_hash"));
         //else if (key == "transparency") m_clipProducer->set("transparency", value.toInt());
     } else if (key == "out") {
         setDuration(GenTime(value.toInt() + 1, KdenliveSettings::project_fps()));
@@ -1282,11 +1171,6 @@ void DocClipBase::updateCutZone(int oldin, int oldout, int in, int out, const QS
     }
 }
 
-QList <CutZoneInfo> DocClipBase::cutZones() const
-{
-    return m_cutZones;
-}
-
 bool DocClipBase::hasVideoCodec(const QString &codec) const
 {
     Mlt::Producer *prod = NULL;
