@@ -486,19 +486,19 @@ void EffectsListWidget::createFavorites(QList <QTreeWidgetItem *>list)
     // Favorites is a pseudo-folder used to store items, not visible to end user, so don't i18n its name
     QTreeWidgetItem *misc = findFolder("Favorites");
     if (misc == NULL) {
-        misc = new QTreeWidgetItem((QTreeWidget*)0, QStringList("Favorites"));
+        misc = new QTreeWidgetItem(this, QStringList(QStringLiteral("Favorites")));
         misc->setData(0, TypeRole, QString::number((int) EFFECT_FOLDER));
         misc->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
-        insertTopLevelItem(0, misc);
     }
     else qDeleteAll(misc->takeChildren());
-    setRootIndex(indexFromItem(misc));
+    setIndentation(0);
     misc->addChildren(list);
     for (int j = 0; j < misc->childCount(); ++j) {
         QTreeWidgetItem *child = misc->child(j);
         child->setHidden(false);
         child->setData(0, Qt::UserRole, EFFECT_FAVORITES);
     }
+    setRootIndex(indexFromItem(misc));
 }
 
 void EffectsListWidget::resetFavorites()
