@@ -39,14 +39,22 @@ class EffectsListWidget : public QTreeWidget
     static const int EFFECT_CUSTOM = 4;
     static const int EFFECT_FAVORITES = 5;
     static const int EFFECT_FOLDER = 6;
+    static const int TRANSITION_TYPE= 7;
+
+    static const int TypeRole = Qt::UserRole;
+    static const int IdRole = TypeRole + 1;
 
     explicit EffectsListWidget(QWidget *parent = 0);
     virtual ~EffectsListWidget();
     const QDomElement currentEffect() const;
     QString currentInfo() const;
-    const QDomElement itemEffect(QTreeWidgetItem *item) const;
-    void initList(QMenu *effectsMenu, KActionCategory *effectActions);
+    static const QDomElement itemEffect(int type, QStringList effectInfo);
+    void initList(QMenu *effectsMenu, KActionCategory *effectActions, QString categoryFile, bool transitionMode);
     void updatePalette();
+    void setRootOnCustomFolder();
+    void resetRoot();
+    void createFavorites(QList <QTreeWidgetItem *>list);
+    void resetFavorites();
 
 protected:
     virtual void dragMoveEvent(QDragMoveEvent *event);
@@ -69,6 +77,7 @@ private:
      * @param found will be set to true if an effect name matches current
      */
     void loadEffects(const EffectsList *effectlist, QIcon icon, QTreeWidgetItem *defaultFolder, const QList<QTreeWidgetItem *> *folders, int type, const QString &current, bool *found);
+    QIcon generateIcon(int size, const QString &name, const QString &group, QDomElement info);
 
 private slots:
     void slotExpandItem(const QModelIndex & index);
