@@ -29,7 +29,8 @@
 #include <QDomElement>
 
 class QLabel;
-
+class QTimeLine;
+class KDualAction;
 
 /**)
  * @class CollapsibleEffect
@@ -63,14 +64,15 @@ public:
     void removeFromGroup();
     QString infoString() const;
     bool isActive() const;
+    bool isEnabled() const;
     /** @brief Should the wheel event be sent to parent widget for scrolling. */
     bool filterWheelEvent;
     /** @brief Parent group was collapsed, update. */
     void groupStateChanged(bool collapsed);
     /** @brief Show / hide up / down buttons. */
     void adjustButtons(int ix, int max);
-    /** @brief Returns true of this effect requires an on monitor adjustable effect scene. */
-    bool needsMonitorEffectScene() const;
+    /** @brief Returns this effect's monitor scene type if any is needed. */
+    MonitorSceneType needsMonitorEffectScene() const;
     /** @brief Set clip in / out points. */
     void setRange(int inPoint , int outPoint);
     /** @brief Import keyframes from a clip's data. */
@@ -80,6 +82,9 @@ public slots:
     void slotSyncEffectsPos(int pos);
     void slotDisable(bool disable, bool emitInfo = true);
     void slotResetEffect();
+    
+private slots:
+    void setWidgetHeight(qreal value);
 
 private slots:
     void slotSwitch();
@@ -106,10 +111,14 @@ private:
     QMenu *m_menu;
     QPoint m_clickPoint;
     EffectInfo m_info;
+    QTimeLine *m_animation;
     /** @brief True if this is a region effect, which behaves in a special way, like a group. */
     bool m_regionEffect;
     /** @brief The add group action. */
     QAction *m_groupAction;
+    KDualAction *m_enabledButton;
+    QLabel *m_colorIcon;
+    QPixmap m_iconPix;
     /** @brief Check if collapsed state changed and inform MLT. */
     void updateCollapsedState();
     
@@ -123,7 +132,7 @@ protected:
 signals:
     void parameterChanged(const QDomElement &, const QDomElement&, int);
     void syncEffectsPos(int);
-    void effectStateChanged(bool, int ix, bool effectNeedsMonitorScene);
+    void effectStateChanged(bool, int ix, MonitorSceneType effectNeedsMonitorScene);
     void deleteEffect(const QDomElement &);
     void activateEffect(int);
     void checkMonitorPosition(int);
