@@ -30,6 +30,8 @@
 
 class EffectsList;
 class ClipItem;
+class Transition;
+class TransitionSettings;
 class ClipController;
 class MltVideoProfile;
 class Monitor;
@@ -40,7 +42,7 @@ class EffectStackView2 : public QWidget
     Q_OBJECT
 
 public:
-    explicit EffectStackView2(QWidget *parent = 0);
+    explicit EffectStackView2(Monitor *projectMonitor, QWidget *parent = 0);
     virtual ~EffectStackView2();
 
     /** @brief Raises @param dock if a clip is loaded. */
@@ -59,27 +61,44 @@ public:
 
     /** @brief Tells the effect editor to update its timecode format. */
     void updateTimecodeFormat();
-    
+
     /** @brief Used to trigger drag effects. */
     virtual bool eventFilter( QObject * o, QEvent * e );
-    
+
     CollapsibleEffect *getEffectByIndex(int ix);
-    
+
     /** @brief Delete currently selected effect. */
     void deleteCurrentEffect();
-    
+
     /** @brief Palette was changed, update style. */
     void updatePalette();
-    
+
+    /** @brief Color theme was changed, update icons. */
+    void refreshIcons();
+
     /** @brief Process dropped xml effect. */
     void processDroppedEffect(QDomElement e, QDropEvent *event);
-    
+
     /** @brief Return the stylesheet required for effect parameters. */
     static const QString getStyleSheet();
 
     /** @brief Import keyframes from the clip metadata */
     void setKeyframes(const QString &data, int maximum);
 
+    /** @brief Returns the transition setting widget for signal/slot connections */
+    TransitionSettings *transitionConfig();
+
+    /** @brief Dis/Enable the effect stack */
+    void disableBinEffects(bool disable);
+    void disableTimelineEffects(bool disable);
+    
+    enum STACKSTATUS {
+        NORMALSTATUS = 0,
+        DISABLEBIN = 1,
+        DISABLETIMELINE = 2,
+        DISABLEALL = 3
+    };
+
 protected:
     void mouseMoveEvent(QMouseEvent * event);
     void mouseReleaseEvent(QMouseEvent * event);
@@ -92,6 +111,8 @@ private:
     ClipController *m_masterclipref;
     /** @brief Current status of the effect stack (if it contains a timeline clip, track or master clip effect. */
     EFFECTMODE m_status;
+    STACKSTATUS m_stateStatus;
+
     /** @brief The track index of currently edited track. */
     int m_trackindex;
 
@@ -105,7 +126,7 @@ private:
     int m_groupIndex;
 
     /** @brief The current effect may require an on monitor scene. */
-    bool m_monitorSceneWanted;
+    MonitorSceneType m_monitorSceneWanted;
 
     /** If in track mode: Info of the edited track to be able to access its duration. */
     TrackInfo m_trackInfo;
@@ -113,6 +134,9 @@ private:
     QList <CollapsibleEffect*> m_effects;
     EffectsList m_currentEffectList;
 
+    QVBoxLayout m_layout;
+    QWidget *m_effect;
+    TransitionSettings *m_transition;
     Ui::EffectStack2_UI m_ui;
 
     /** @brief Contains info about effect like is it a track effect, which monitor displays it,... */
@@ -137,7 +161,11 @@ public slots:
     /** @brief Sets the clip whose effect list should be managed.
     * @param c Clip whose effect list should be managed */
     void slotClipItemSelected(ClipItem* c, Monitor *m = NULL);
-    
+    /** @brief An effect parameter was changed, refresh effect stack if it was displaying it.
+    * @param c Clip controller whose effect list should be managed */
+    void slotRefreshMasterClipEffects(ClipController* c, Monitor *m);
+    /** @brief Display effects for the selected Bin clip.
+    * @param c Clip controller whose effect list should be managed */
     void slotMasterClipItemSelected(ClipController* c, Monitor *m = NULL);
 
     /** @brief Update the clip range (in-out points)
@@ -148,6 +176,8 @@ public slots:
    
     /** @brief Check if the mouse wheel events should be used for scrolling the widget view. */
     void slotCheckWheelEventFilter();
+    
+    void slotTransitionItemSelected(Transition* t, int nextTrack, const QPoint &p, bool update);
 
 private slots:
 
@@ -178,7 +208,7 @@ private slots:
     void slotRenderPos(int pos);
 
     /** @brief Called whenever an effect is enabled / disabled by user. */
-    void slotUpdateEffectState(bool disable, int index, bool needsMonitorEffectScene);
+    void slotUpdateEffectState(bool disable, int index, MonitorSceneType needsMonitorEffectScene);
 
     void slotSetCurrentEffect(int ix);
     
@@ -223,6 +253,7 @@ private slots:
 signals:
     void removeEffect(ClipItem*, int, const QDomElement&);
     void removeMasterEffect(const QString &id, const QDomElement&);
+    void addMasterEffect(const QString &id, const QDomElement&);
     /**  Parameters for an effect changed, update the filter in timeline */
     void updateEffect(ClipItem*, int, const QDomElement&, const QDomElement &, int,bool);
     /** An effect in stack was moved, we need to regenerate
@@ -241,7 +272,7 @@ signals:
     void displayMessage(const QString&, int);
     void showComments(bool show);
     void startFilterJob(const ItemInfo &info, const QString &clipId, QMap<QString, QString>&, QMap<QString, QString>&, QMap<QString, QString>&);
-    void addEffect(ClipItem*,const QDomElement &);
+    void addEffect(ClipItem*,const QDomElement &,int);
     void importClipKeyframes(GraphicsRectItem = AVWidget, QMap<QString,QString> data = QMap<QString,QString>());
 };
 
