@@ -21,7 +21,6 @@
 #include <config-kdenlive.h>
 #include "mainwindow.h"
 
-
 #include <KAboutData>
 #include <QDebug>
 
@@ -31,10 +30,14 @@
 #include <KDBusService>
 #include <QCommandLineParser>
 #include <QCommandLineOption>
-
+#include <QProcess>
 
 int main(int argc, char *argv[])
 {
+#if defined(Q_OS_UNIX) && !defined(Q_OS_MAC)
+    QCoreApplication::setAttribute(Qt::AA_X11InitThreads);
+#endif
+    
     KLocalizedString::setApplicationDomain("kdenlive");
 
     // Init application
@@ -45,12 +48,11 @@ int main(int argc, char *argv[])
                          i18n("Kdenlive"), KDENLIVE_VERSION,
                          i18n("An open source video editor."),
                          KAboutLicense::GPL,
-                         i18n("Copyright © 2007–2015 Kdenlive authors"),
-                         i18n("Please report bugs to http://kdenlive.org/mantis"),
-                         "http://kdenlive.org",
-                         "http://bugs.kdenlive.org");
-    aboutData.addAuthor(i18n("Jean-Baptiste Mardelle"), i18n("MLT and KDE SC 4 porting, main developer and maintainer"), "jb@kdenlive.org");
-    aboutData.addAuthor(i18n("Vincent Pinon"), i18n("Interim maintainer, bugs fixing, minor functions, profiles updates, etc."), "vpinon@april.org");
+                         i18n("Copyright © 2007–2016 Kdenlive authors"),
+                         i18n("Please report bugs to http://bugs.kde.org"),
+                         "https://kdenlive.org");
+    aboutData.addAuthor(i18n("Jean-Baptiste Mardelle"), i18n("MLT and KDE SC 4 / KF5 port, main developer and maintainer"), "jb@kdenlive.org");
+    aboutData.addAuthor(i18n("Vincent Pinon"), i18n("Interim maintainer, KF5 port, bugs fixing, minor functions, profiles updates, etc."), "vpinon@april.org");
     aboutData.addAuthor(i18n("Laurent Montel"), i18n("Bugs fixing, clean up code, optimization etc."), "montel@kde.org");
     aboutData.addAuthor(i18n("Marco Gittler"), i18n("MLT transitions and effects, timeline, audio thumbs"), "g.marco@freenet.de");
     aboutData.addAuthor(i18n("Dan Dennedy"), i18n("Bug fixing, etc."), "dan@dennedy.org");
@@ -92,21 +94,13 @@ int main(int argc, char *argv[])
     // Register DBus service
     KDBusService programDBusService;
 
-    MainWindow* window = 0;
-
     // see if we are starting with session management
-    if (app.isSessionRestored()) {
-        int n = 1;
-        while (KMainWindow::canBeRestored(n)) {
-            const QString className = KXmlGuiWindow::classNameOfToplevel(n);
-            if (className == QLatin1String("MainWindow")) {
-                window = new MainWindow();
-                window->restore(n);
-            } else {
-                qWarning() << "Unknown class " << className << " in session saved data!";
-            }
-            ++n;
-        }
+    if (qApp->isSessionRestored()){
+	  int n = 1;
+	  while (KMainWindow::canBeRestored(n)){
+	      (new MainWindow())->restore(n);
+	      n++;
+	  }
     } else {
         QString clipsToLoad = parser.value("i");
         QString mltPath = parser.value("mlt-path");
@@ -118,9 +112,19 @@ int main(int argc, char *argv[])
             QUrl startup = QUrl::fromLocalFile(currentPath.endsWith(QDir::separator()) ? currentPath : currentPath + QDir::separator());
             url = startup.resolved(url);
         }
-        window = new MainWindow(mltPath, url, clipsToLoad);
+        MainWindow* window = new MainWindow(mltPath, url, clipsToLoad);
         window->show();
     }
     int result = app.exec();
+    
+    if (EXIT_RESTART == result) {
+        qDebug() << "restarting app";
+        QProcess* restart = new QProcess;
+        restart->start(app.applicationFilePath(), QStringList());
+        restart->waitForReadyRead();
+        restart->waitForFinished(1000);
+        result = EXIT_SUCCESS;
+    }
+    
     return result;
 }
