@@ -252,6 +252,8 @@ private:
     QListWidget *m_effectBasket;
     /** @brief Update statusbar stylesheet (in case of color theme change). */
     void setStatusBarStyleSheet(const QPalette &p);
+    /** @brief Update widget style. */
+    void doChangeStyle();
 
 public slots:
     void slotGotProgressInfo(const QString &message, int progress, MessageType type = DefaultMessage);
@@ -265,6 +267,8 @@ public slots:
     void slotPreferences(int page = -1, int option = -1);
     void connectDocument();
     void slotTimelineClipSelected(ClipItem* item, bool raise = true);
+    /** @brief Reload project profile in config dialog if changed. */
+    void slotRefreshProfiles();
 
 private slots:
     /** @brief Shows the shortcut dialog. */
@@ -277,7 +281,6 @@ private slots:
     void slotUpdateMousePosition(int pos);
     void slotUpdateProjectDuration(int pos);
     void slotAddEffect(const QDomElement &effect);
-    void slotEditProfiles();
     void slotEditProjectSettings();
 
     /** @brief Turns automatic splitting of audio and video on/off. */
@@ -441,6 +444,9 @@ private slots:
     void slotReloadTheme();
     /** @brief Close Kdenlive and try to restart it */
     void slotRestart();
+    void triggerKey(QKeyEvent* ev);
+
+    void slotChangeStyle(QAction *a);
 
 signals:
     Q_SCRIPTABLE void abortRenderJob(const QString &url);
