@@ -193,24 +193,17 @@ ClipPropertiesController::ClipPropertiesController(Timecode tc, ClipController *
         spin2->setObjectName("force_aspect_den_value");
         hlay->addWidget(spin2);
         if (force_ar_num == 0) {
-            // calculate current ratio
-            box->setChecked(false);
+            // use current ratio
+            int num = m_properties.get_int("meta.media.sample_aspect_num");
+            int den = m_properties.get_int("meta.media.sample_aspect_den");
+            if (den == 0) {
+                num = 1;
+                den = 1;
+            }
             spin1->setEnabled(false);
             spin2->setEnabled(false);
-            int width = m_controller->profile()->width();
-            int height = m_controller->profile()->height();
-            if (width > 0 && height > 0) {
-                if (qAbs(100 * width / height - 133) < 3) {
-                    width = 4;
-                    height = 3;
-                }
-                else if (qAbs(100 * width / height - 177) < 3) {
-                    width = 16;
-                    height = 9;
-                }
-                spin1->setValue(width);
-                spin2->setValue(height);
-            }
+            spin1->setValue(num);
+            spin2->setValue(den);
         }
         else {
             box->setChecked(true);
@@ -613,21 +606,21 @@ void ClipPropertiesController::fillProperties(QTreeWidget *tree)
             propertyMap.append(QStringList() << i18n("Frame size") << QString::number(width) + "x" + QString::number(height));
 
             snprintf(property, sizeof(property), "meta.media.%d.stream.frame_rate", vindex);
-            double fps = m_controller->double_property(property);
-            if (fps > 0) {
-                    propertyMap.append(QStringList() << i18n("Frame rate") << QString::number(fps, 'g', 3));
+            QString fpsValue = m_controller->property(property);
+            if (!fpsValue.isEmpty()) {
+                propertyMap.append(QStringList() << i18n("Frame rate") << fpsValue);
             } else {
                 int rate_den = m_controller->int_property("meta.media.frame_rate_den");
                 if (rate_den > 0) {
-                    double fps = (double) m_controller->int_property("meta.media.frame_rate_num") / rate_den;
-                    propertyMap.append(QStringList() << i18n("Frame rate") << QString::number(fps, 'g', 3));
+                    double fps = (double) m_controller->int_property(QStringLiteral("meta.media.frame_rate_num")) / rate_den;
+                    propertyMap.append(QStringList() << i18n("Frame rate") << QString::number(fps, 'f', 2));
                 }
             }
 
             snprintf(property, sizeof(property), "meta.media.%d.codec.bit_rate", vindex);
-            int bitrate = m_controller->int_property(property);
+            int bitrate = m_controller->int_property(property) / 1000;
             if (bitrate > 0) {
-                propertyMap.append(QStringList() << i18n("Video bitrate") << KIO::convertSize(bitrate) + "/" + i18nc("seconds", "s"));
+                propertyMap.append(QStringList() << i18n("Video bitrate") << QString::number(bitrate) + QStringLiteral(" ") + i18nc("Kilobytes per seconds", "kb/s"));
             }
 
             int scan = m_controller->int_property("meta.media.progressive");
@@ -638,9 +631,10 @@ void ClipPropertiesController::fillProperties(QTreeWidget *tree)
                 // Read media aspect ratio
                 par = m_controller->double_property("aspect_ratio");
             }
-            propertyMap.append(QStringList() << i18n("Pixel aspect ratio") << QString::number(par, 'g', 3));
-            propertyMap.append(QStringList() << i18n("Pixel format") << m_controller->videoCodecProperty("pix_fmt"));
-            int colorspace = m_controller->videoCodecProperty("colorspace").toInt();
+
+            propertyMap.append(QStringList() << i18n("Pixel aspect ratio") << QString::number(par, 'f', 3));
+            propertyMap.append(QStringList() << i18n("Pixel format") << m_controller->videoCodecProperty(QStringLiteral("pix_fmt")));
+            int colorspace = m_controller->videoCodecProperty(QStringLiteral("colorspace")).toInt();
             propertyMap.append(QStringList() << i18n("Colorspace") << ProfilesDialog::getColorspaceDescription(colorspace));
         }
         if (default_audio > -1) {
@@ -656,12 +650,12 @@ void ClipPropertiesController::fillProperties(QTreeWidget *tree)
 
             snprintf(property, sizeof(property), "meta.media.%d.codec.sample_rate", default_audio);
             int srate = m_controller->int_property(property);
-            propertyMap.append(QStringList() << i18n("Audio frequency") << QString::number(srate));
+            propertyMap.append(QStringList() << i18n("Audio frequency") << QString::number(srate) + QStringLiteral(" ") + i18nc("Herz", "Hz"));
 
             snprintf(property, sizeof(property), "meta.media.%d.codec.bit_rate", default_audio);
-            int bitrate = m_controller->int_property(property);
+            int bitrate = m_controller->int_property(property) / 1000;
             if (bitrate > 0) {
-                propertyMap.append(QStringList() << i18n("Audio bitrate") << KIO::convertSize(bitrate) + "/" + i18nc("seconds", "s"));
+                propertyMap.append(QStringList() << i18n("Audio bitrate") << QString::number(bitrate) + QStringLiteral(" ") + i18nc("Kilobytes per seconds", "kb/s"));
             }
         }
     }
