@@ -91,6 +91,22 @@ bool QuickEventEater::eventFilter(QObject *obj, QEvent *event)
     return QObject::eventFilter(obj, event);
 }
 
+QuickMonitorEventEater::QuickMonitorEventEater(Monitor *parent) : QObject(parent)
+  , m_monitor(parent)
+{
+}
+
+bool QuickMonitorEventEater::eventFilter(QObject *obj, QEvent *event)
+{
+    if (event->type() == QEvent::KeyPress) {
+        QKeyEvent *ev = static_cast< QKeyEvent* >(event);
+        if (ev) {
+            m_monitor->doKeyPressEvent(ev);
+            return true;
+        }
+    }
+    return QObject::eventFilter(obj, event);
+}
 
 
 Monitor::Monitor(Kdenlive::MonitorId id, MonitorManager *manager, QWidget *parent) :
@@ -125,12 +141,16 @@ Monitor::Monitor(Kdenlive::MonitorId id, MonitorManager *manager, QWidget *paren
     glayout->setContentsMargins(0, 0, 0, 0);
     // Create QML OpenGL widget
     m_glMonitor = new GLWidget();
+    connect(m_glMonitor, SIGNAL(passKeyEvent(QKeyEvent*)), this, SLOT(doKeyPressEvent(QKeyEvent*)));
     m_videoWidget = QWidget::createWindowContainer(qobject_cast<QWindow*>(m_glMonitor));
     m_videoWidget->setAcceptDrops(true);
     QuickEventEater *leventEater = new QuickEventEater(this);
     m_videoWidget->installEventFilter(leventEater);
     connect(leventEater, &QuickEventEater::addEffect, this, &Monitor::slotAddEffect);
 
+    QuickMonitorEventEater *monitorEventEater = new QuickMonitorEventEater(this);
+    m_glWidget->installEventFilter(monitorEventEater);
+
     glayout->addWidget(m_videoWidget, 0, 0);
     m_verticalScroll = new QScrollBar(Qt::Vertical);
     glayout->addWidget(m_verticalScroll, 0, 1);
@@ -249,6 +269,9 @@ Monitor::Monitor(Kdenlive::MonitorId id, MonitorManager *manager, QWidget *paren
         m_effectCompare->setInactiveIcon(KoIconUtils::themedIcon("view-split-effect"));
         m_effectCompare->setActiveIcon(KoIconUtils::themedIcon("view-unsplit-effect"));
         m_effectCompare->setActive(false);
+        m_effectCompare->setCheckable(true);
+        m_effectCompare->setChecked(false);
+        m_effectCompare->setEnabled(false);
         m_toolbar->addSeparator();
         m_toolbar->addAction(m_effectCompare);
         connect(m_effectCompare, &KDualAction::activeChanged, this, &Monitor::slotSwitchCompare);
@@ -341,7 +364,7 @@ void Monitor::refreshIcons()
     for (int i = 0; i < allMenus.count(); i++) {
         QAction *m = allMenus.at(i);
         QIcon ic = m->icon();
-        if (ic.isNull()) continue;
+        if (ic.isNull() || ic.name().isEmpty()) continue;
         QIcon newIcon = KoIconUtils::themedIcon(ic.name());
         m->setIcon(newIcon);
     }
@@ -349,11 +372,11 @@ void Monitor::refreshIcons()
     for (int i = 0; i < allButtons.count(); i++) {
         KDualAction *m = allButtons.at(i);
         QIcon ic = m->activeIcon();
-        if (ic.isNull()) continue;
+        if (ic.isNull() || ic.name().isEmpty()) continue;
         QIcon newIcon = KoIconUtils::themedIcon(ic.name());
         m->setActiveIcon(newIcon);
         ic = m->inactiveIcon();
-        if (ic.isNull()) continue;
+        if (ic.isNull() || ic.name().isEmpty()) continue;
         newIcon = KoIconUtils::themedIcon(ic.name());
         m->setInactiveIcon(newIcon);
     }
@@ -662,7 +685,7 @@ void Monitor::slotSwitchFullScreen(bool minimizeOnly)
             // Move monitor widget to the second screen (one screen for Kdenlive, the other one for the Monitor widget
             //int currentScreen = QApplication::desktop()->screenNumber(this);
             for (int i = 0; screen == -1 && i < QApplication::desktop()->screenCount(); i++) {
-            if (i != QApplication::desktop()->screenNumber(this))
+            if (i != QApplication::desktop()->screenNumber(this->parentWidget()->parentWidget()))
                 screen = i;
             }
         }
@@ -797,6 +820,22 @@ void Monitor::mouseDoubleClickEvent(QMouseEvent * event)
     event->accept();
 }
 
+void Monitor::keyPressEvent(QKeyEvent* event)
+{
+    if (event->key()==Qt::Key_Escape) {
+        slotSwitchFullScreen();
+        event->accept();
+        return;
+    }
+    if (m_glWidget->isFullScreen()) {
+        event->ignore();
+        emit passKeyPress(event);
+        return;
+    }
+    QWidget::keyPressEvent(event);
+}
+
+
 void Monitor::slotMouseSeek(int eventDelta, bool fast)
 {
     if (fast) {
@@ -1061,18 +1100,9 @@ void Monitor::start()
 
 void Monitor::refreshMonitor(bool visible)
 {
-    if (visible && render) {
-        if (!slotActivateMonitor()) {
-            // the monitor was already active, simply refreshClipThumbnail
-            render->refreshIfActive();
-        }
-    }
-}
-
-void Monitor::refreshMonitor()
-{
-    if (isActive()) {
-        render->refreshIfActive();
+    if (visible && isActive()) {
+        m_glMonitor->raise();
+        render->doRefresh();
     }
 }
 
@@ -1150,14 +1180,33 @@ void Monitor::updateClipProducer(const QString &playlist)
     render->play(1.0);
 }
 
+void Monitor::slotSeekController(ClipController *controller, int pos)
+{
+    if (controller != m_controller) {
+        slotOpenClip(controller, pos, -1);
+    }
+    else slotSeek(pos);
+}
+
 void Monitor::slotOpenClip(ClipController *controller, int in, int out)
 {
     if (render == NULL) return;
     bool sameClip = controller == m_controller && controller != NULL;
     m_controller = controller;
-    if (m_rootItem && m_rootItem->objectName() != "root" && !sameClip) {
+    if (m_rootItem && m_rootItem->objectName() != QLatin1String("root") && !sameClip) {
+        // changed clip, disable split effect
+        if (m_splitProducer) {
+            m_effectCompare->blockSignals(true);
+            m_effectCompare->setActive(false);
+            m_effectCompare->setChecked(false);
+            m_effectCompare->blockSignals(false);
+            delete m_splitEffect;
+            m_splitProducer = NULL;
+            m_splitEffect = NULL;
+        }
         loadMasterQml();
     }
+    //bool hasEffects;
     if (controller) {
 	if (m_recManager->toolbar()->isVisible()) {
 	      // we are in record mode, don't display clip
@@ -1169,18 +1218,29 @@ void Monitor::slotOpenClip(ClipController *controller, int in, int out)
 	    m_ruler->setZone(in, out);
 	    setClipZone(QPoint(in, out));
 	}
+	//hasEffects =  controller->hasEffects();
     }
     else {
         render->setProducer(NULL, -1, isActive());
+        //hasEffects = false;
     }
-    if (m_splitProducer) {
-        m_effectCompare->blockSignals(true);
+}
+
+void Monitor::enableCompare(int effectsCount)
+{
+    if (!m_effectCompare) return;
+    if (effectsCount == 0) {
+        m_effectCompare->setEnabled(false);
         m_effectCompare->setChecked(false);
-        m_effectCompare->blockSignals(false);
-        delete m_splitEffect;
-        m_splitProducer = NULL;
-        m_splitEffect = NULL;
-        loadMasterQml();
+        m_effectCompare->setActive(false);
+        if (m_splitProducer) {
+            delete m_splitEffect;
+            m_splitProducer = NULL;
+            m_splitEffect = NULL;
+            loadMasterQml();
+        }
+    } else {
+        m_effectCompare->setEnabled(true);
     }
 }
 
@@ -1333,7 +1393,7 @@ void Monitor::slotShowEffectScene(MonitorSceneType sceneType, bool temporary)
 {
     if (!temporary) m_lastMonitorSceneType = sceneType;
     if (sceneType == MonitorSceneGeometry) {
-        if (!m_rootItem || m_rootItem->objectName() != "rooteffectscene") {
+        if (!m_rootItem || m_rootItem->objectName() != QLatin1String("rooteffectscene")) {
             m_glMonitor->setSource(QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("kdenlivemonitoreffectscene.qml"))));
             m_rootItem = m_glMonitor->rootObject();
             QObject::connect(m_rootItem, SIGNAL(addKeyframe()), this, SIGNAL(addKeyframe()), Qt::UniqueConnection);
@@ -1342,7 +1402,7 @@ void Monitor::slotShowEffectScene(MonitorSceneType sceneType, bool temporary)
         }
     }
     else if (sceneType == MonitorSceneCorners) {
-        if (!m_rootItem || m_rootItem->objectName() != "rootcornerscene") {
+        if (!m_rootItem || m_rootItem->objectName() != QLatin1String("rootcornerscene")) {
             m_glMonitor->setSource(QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("kdenlivemonitorcornerscene.qml"))));
             m_rootItem = m_glMonitor->rootObject();
             QObject::connect(m_rootItem, SIGNAL(addKeyframe()), this, SIGNAL(addKeyframe()), Qt::UniqueConnection);
@@ -1352,7 +1412,7 @@ void Monitor::slotShowEffectScene(MonitorSceneType sceneType, bool temporary)
     }
     else if (sceneType == MonitorSceneRoto) {
         // TODO
-        if (!m_rootItem || m_rootItem->objectName() != "rootcornerscene") {
+        if (!m_rootItem || m_rootItem->objectName() != QLatin1String("rootcornerscene")) {
             m_glMonitor->setSource(QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::DataLocation, QStringLiteral("kdenlivemonitorcornerscene.qml"))));
             m_rootItem = m_glMonitor->rootObject();
             QObject::connect(m_rootItem, SIGNAL(addKeyframe()), this, SIGNAL(addKeyframe()), Qt::UniqueConnection);
@@ -1360,8 +1420,13 @@ void Monitor::slotShowEffectScene(MonitorSceneType sceneType, bool temporary)
             m_glMonitor->slotShowEffectScene(sceneType);
         }
     }
-    else if (m_rootItem && m_rootItem->objectName() != "root")  {
-        loadMasterQml();
+    else if (m_rootItem && m_rootItem->objectName() != QLatin1String("root") && m_rootItem->objectName() != QLatin1String("rootsplit"))  {
+        if (m_effectCompare && m_effectCompare->isEnabled() && m_effectCompare->isActive()) {
+            if (m_rootItem->objectName() != QLatin1String("rootsplit")) {
+                slotSwitchCompare(true);
+            }
+        } 
+        else loadMasterQml();
     }
     if (m_sceneVisibilityAction) m_sceneVisibilityAction->setChecked(sceneType != MonitorSceneNone);
 }
@@ -1513,18 +1578,23 @@ void Monitor::warningMessage(const QString &text)
 
 void Monitor::slotSwitchCompare(bool enable)
 {
-    if (m_controller == NULL) {
-        m_effectCompare->blockSignals(true);
-        m_effectCompare->setChecked(false);
-        m_effectCompare->blockSignals(false);
-        warningMessage(i18n("Select a clip in project bin to compare effect"));
+    if (m_controller == NULL || !m_controller->hasEffects()) {
+        // disable split effect
+        enableCompare(0);
+        if (m_controller) {
+            warningMessage(i18n("Clip has no effects"));
+        }
+        else {
+            warningMessage(i18n("Select a clip in project bin to compare effect"));
+        }
         return;
     }
-    if (!m_controller->hasEffects()) {
-        warningMessage(i18n("Clip has no effects"));
-    }
     int pos = position().frames(m_monitorManager->timecode().fps());
     if (enable) {
+        if ((m_rootItem && m_rootItem->objectName() == QLatin1String("rootsplit"))) {
+            // Split scene is already active
+            return;
+        }
         m_splitEffect = new Mlt::Filter(*profile(), "frei0r.scale0tilt");
         if (m_splitEffect && m_splitEffect->is_valid()) {
             m_splitEffect->set("Clip left", 0.5);
@@ -1598,7 +1668,7 @@ void Monitor::slotAdjustEffectCompare()
         m_rootItem->setProperty("realpercent", percent);
     }
     if (m_splitEffect) m_splitEffect->set("Clip left", percent);
-    render->refreshIfActive();
+    render->doRefresh();
 }
 
 ProfileInfo Monitor::profileInfo() const
@@ -1645,4 +1715,7 @@ bool Monitor::stopCapture()
     return true;
 }
 
-
+void Monitor::doKeyPressEvent(QKeyEvent *ev)
+{
+    keyPressEvent(ev);
+}
