@@ -65,6 +65,20 @@ signals:
     void addEffect(QDomElement);
 };
 
+class QuickMonitorEventEater : public QObject
+{
+    Q_OBJECT
+public:
+    explicit QuickMonitorEventEater(Monitor *parent);
+
+protected:
+    bool eventFilter(QObject *obj, QEvent *event);
+    
+private:
+    Monitor *m_monitor;
+
+};
+
 class Monitor : public AbstractMonitor
 {
     Q_OBJECT
@@ -121,12 +135,15 @@ public:
     /** @brief Returns the action displaying record toolbar */
     QAction *recAction();
     void refreshIcons();
+    /** @brief Enable or disable the effect compare feature depending on effects presence */
+    void enableCompare(int effectsCount);
 
 protected:
     void mousePressEvent(QMouseEvent * event);
     void mouseReleaseEvent(QMouseEvent * event);
     void mouseDoubleClickEvent(QMouseEvent * event);
     void resizeEvent(QResizeEvent *event);
+    void keyPressEvent(QKeyEvent* event);
 
     /** @brief Move to another position on mouse wheel event.
      *
@@ -223,8 +240,9 @@ public slots:
     void updateClipProducer(Mlt::Producer *prod);
     void updateClipProducer(const QString &playlist);
     void slotOpenClip(ClipController *controller, int in = -1, int out = -1);
-    void refreshMonitor(bool visible);
-    void refreshMonitor();
+    /** @brief Seek clip monitor to a requested position. */
+    void slotSeekController(ClipController *controller, int pos);
+    void refreshMonitor(bool visible = true);
     void slotSeek(int pos);
     void stop();
     void start();
@@ -265,6 +283,8 @@ public slots:
     void slotSwitchRec(bool enable);
     /** @brief Request QImage of current frame */
     void slotGetCurrentImage();
+    /** @brief Pass keypress event to mainwindow */
+    void doKeyPressEvent(QKeyEvent *ev);
 
 signals:
     void renderPosition(int);
@@ -286,6 +306,7 @@ signals:
     void refreshCurrentClip();
     void addEffect(QDomElement);
     void addMasterEffect(QString,QDomElement);
+    void passKeyPress(QKeyEvent*);
 };
 
 #endif
