@@ -425,7 +425,7 @@ void MonitorManager::refreshIcons()
     for (int i = 0; i < allMenus.count(); i++) {
         QAction *m = allMenus.at(i);
         QIcon ic = m->icon();
-        if (ic.isNull()) continue;
+        if (ic.isNull() || ic.name().isEmpty()) continue;
         QIcon newIcon = KoIconUtils::themedIcon(ic.name());
         m->setIcon(newIcon);
     }
