@@ -37,7 +37,16 @@ class AbstractClipJob : public QObject
     Q_OBJECT
 
 public:
-    enum JOBTYPE { NOJOBTYPE = 0, PROXYJOB = 1, CUTJOB = 2, MLTJOB = 3, TRANSCODEJOB = 4, FILTERCLIPJOB = 5, THUMBJOB = 5 };
+    enum JOBTYPE {
+        NOJOBTYPE = 0,
+        PROXYJOB = 1,
+        CUTJOB = 2,
+        MLTJOB = 3,
+        TRANSCODEJOB = 4,
+        FILTERCLIPJOB = 5,
+        THUMBJOB = 5,
+        ANALYSECLIPJOB = 6
+    };
     AbstractClipJob(JOBTYPE type, ClipType cType, const QString &id);
     virtual ~ AbstractClipJob();
     ClipType clipType;
