@@ -22,14 +22,20 @@ NotesPlugin::NotesPlugin(ProjectManager *projectManager) :
     QObject(projectManager)
 {
     m_widget = new NotesWidget();
-    connect(m_widget, SIGNAL(insertNotesTimecode()), SLOT(slotInsertTimecode()));
+    connect(m_widget, &NotesWidget::insertNotesTimecode, this, &NotesPlugin::slotInsertTimecode);
     m_widget->setTabChangesFocus(true);
     m_widget->setPlaceholderText(i18n("Enter your project notes here ..."));
-    pCore->window()->addDock(i18n("Project Notes"), "notes_widget", m_widget);
-
+    m_notesDock = pCore->window()->addDock(i18n("Project Notes"), "notes_widget", m_widget);
+    m_notesDock->close();
     connect(projectManager, SIGNAL(docOpened(KdenliveDoc*)), SLOT(setProject(KdenliveDoc*)));
 }
 
+NotesPlugin::~NotesPlugin()
+{
+    delete m_widget;
+    delete m_notesDock;
+}
+
 void NotesPlugin::setProject(KdenliveDoc* document)
 {
     connect(m_widget, SIGNAL(seekProject(int)), pCore->monitorManager()->projectMonitor()->render, SLOT(seekToFrame(int)));
@@ -48,4 +54,9 @@ NotesWidget* NotesPlugin::widget()
     return m_widget;
 }
 
+void NotesPlugin::clear()
+{
+    m_widget->clear();
+}
+
 
