@@ -20,6 +20,8 @@
 
 #include "projectcommands.h"
 #include "projectlist.h"
+#include "bin/projectclip.h"
+#include "doc/kdenlivedoc.h"
 
 #include <klocalizedstring.h>
 
@@ -38,18 +40,25 @@ AddClipCutCommand::AddClipCutCommand(ProjectList *list, const QString &id, int i
 // virtual
 void AddClipCutCommand::undo()
 {
-    if (m_remove)
+    Q_UNUSED(m_list)
+    Q_UNUSED(m_id)
+    Q_UNUSED(m_in)
+    Q_UNUSED(m_out)
+    Q_UNUSED(m_desc)
+    Q_UNUSED(m_newItem)
+    Q_UNUSED(m_remove)
+    /*if (m_remove)
         m_list->addClipCut(m_id, m_in, m_out, m_desc, m_newItem);
     else
-        m_list->removeClipCut(m_id, m_in, m_out);
+        m_list->removeClipCut(m_id, m_in, m_out);*/
 }
 // virtual
 void AddClipCutCommand::redo()
 {
-    if (m_remove)
+    /*if (m_remove)
         m_list->removeClipCut(m_id, m_in, m_out);
     else
-        m_list->addClipCut(m_id, m_in, m_out, m_desc, m_newItem);
+        m_list->addClipCut(m_id, m_in, m_out, m_desc, m_newItem);*/
 }
 
 AddFolderCommand::AddFolderCommand(ProjectList *view, const QString &folderName, const QString &clipId, bool doIt, QUndoCommand *parent) :
@@ -67,41 +76,22 @@ AddFolderCommand::AddFolderCommand(ProjectList *view, const QString &folderName,
 // virtual
 void AddFolderCommand::undo()
 {
-    if (m_doIt)
+    Q_UNUSED(m_view)
+    Q_UNUSED(m_name)
+    Q_UNUSED(m_id)
+    Q_UNUSED(m_doIt)
+    /*if (m_doIt)
         m_view->slotAddFolder(m_name, m_id, true);
     else
-        m_view->slotAddFolder(m_name, m_id, false);
+        m_view->slotAddFolder(m_name, m_id, false);*/
 }
 // virtual
 void AddFolderCommand::redo()
 {
-    if (m_doIt)
+    /*if (m_doIt)
         m_view->slotAddFolder(m_name, m_id, false);
     else
-        m_view->slotAddFolder(m_name, m_id, true);
-}
-
-EditClipCommand::EditClipCommand(ProjectList *list, const QString &id, const QMap <QString, QString> &oldparams, const QMap <QString, QString> &newparams, bool doIt, QUndoCommand * parent) :
-        QUndoCommand(parent),
-        m_list(list),
-        m_oldparams(oldparams),
-        m_newparams(newparams),
-        m_id(id),
-        m_doIt(doIt)
-{
-    setText(i18n("Edit clip"));
-}
-// virtual
-void EditClipCommand::undo()
-{
-    m_list->slotUpdateClipProperties(m_id, m_oldparams);
-}
-// virtual
-void EditClipCommand::redo()
-{
-    if (m_doIt)
-        m_list->slotUpdateClipProperties(m_id, m_newparams);
-    m_doIt = true;
+        m_view->slotAddFolder(m_name, m_id, true);*/
 }
 
 EditClipCutCommand::EditClipCutCommand(ProjectList *list, const QString &id, const QPoint &oldZone, const QPoint &newZone, const QString &oldComment, const QString &newComment, bool doIt, QUndoCommand * parent) :
@@ -119,14 +109,20 @@ EditClipCutCommand::EditClipCutCommand(ProjectList *list, const QString &id, con
 // virtual
 void EditClipCutCommand::undo()
 {
-    m_list->doUpdateClipCut(m_id, m_newZone, m_oldZone, m_oldComment);
+    Q_UNUSED(m_list)
+    Q_UNUSED(m_id)
+    Q_UNUSED(m_oldZone)
+    Q_UNUSED(m_newZone)
+    Q_UNUSED(m_oldComment)
+    Q_UNUSED(m_newComment)
+    Q_UNUSED(m_doIt)
+    //m_list->doUpdateClipCut(m_id, m_newZone, m_oldZone, m_oldComment);
 }
 // virtual
 void EditClipCutCommand::redo()
 {
-    if (m_doIt)
-        m_list->doUpdateClipCut(m_id, m_oldZone, m_newZone, m_newComment);
-    m_doIt = true;
+    /*if (m_doIt)
+        m_list->doUpdateClipCut(m_id, m_oldZone, m_newZone, m_newComment); */
 }
 
 EditFolderCommand::EditFolderCommand(ProjectList *view, const QString &newfolderName, const QString &oldfolderName, const QString &clipId, bool doIt, QUndoCommand *parent) :
@@ -142,11 +138,40 @@ EditFolderCommand::EditFolderCommand(ProjectList *view, const QString &newfolder
 // virtual
 void EditFolderCommand::undo()
 {
-    m_view->slotAddFolder(m_oldname, m_id, false, true);
+    Q_UNUSED(m_view)
+    Q_UNUSED(m_name)
+    Q_UNUSED(m_oldname)
+    Q_UNUSED(m_id)
+    Q_UNUSED(m_doIt)
+    //m_view->slotAddFolder(m_oldname, m_id, false, true);
 }
 // virtual
 void EditFolderCommand::redo()
 {
-    if (m_doIt) m_view->slotAddFolder(m_name, m_id, false, true);
-    m_doIt = true;
+    //if (m_doIt) m_view->slotAddFolder(m_name, m_id, false, true);
+}
+
+AddMarkerCommand::AddMarkerCommand(ProjectClip *clip, QList <CommentedTime> &oldMarkers, QList <CommentedTime> &newMarkers, QUndoCommand * parent) :
+        QUndoCommand(parent),
+        m_clip(clip),
+        m_oldMarkers(oldMarkers),
+        m_newMarkers(newMarkers)
+{
+    if (m_newMarkers.isEmpty()) return;
+    if (m_newMarkers.first().markerType() < 0)
+        setText(i18n("Delete marker"));
+    else if (m_oldMarkers.first().comment().isEmpty())
+        setText(i18n("Add marker"));
+    else
+        setText(i18n("Edit marker"));
+}
+// virtual
+void AddMarkerCommand::undo()
+{
+    m_clip->addMarkers(m_oldMarkers);
+}
+// virtual
+void AddMarkerCommand::redo()
+{
+    m_clip->addMarkers(m_newMarkers);
 }
