@@ -26,6 +26,7 @@ class KdenliveDoc;
 class NotesPlugin;
 class QAction;
 class QUrl;
+class QProgressDialog;
 class KAutoSaveFile;
 
 /**
@@ -53,6 +54,8 @@ public:
     void doOpenFile(const QUrl &url, KAutoSaveFile *stale);
     KRecentFilesAction *recentFilesAction();
     void prepareSave();
+    /** @brief Disable all bin effects in current project */
+    void disableBinEffects(bool disable);
 
 public slots:
     void newFile(bool showProjectSettings = true, bool force = false);
@@ -69,6 +72,8 @@ public slots:
     /** @brief Shows a save file dialog for saving the project.
     * @return Whether the file was saved. */
     bool saveFileAs();
+    void slotSaveSelection();
+
 
     /** @brief Set properties to match outputFileName and save the document.
      * Creates an autosave version of the output file too, at
@@ -91,6 +96,12 @@ public slots:
     /** @brief Update project and monitors profiles */
     void slotResetProfiles();
 
+    /** @brief Dis/enable all timeline effects */
+    void slotDisableTimelineEffects(bool disable);
+
+    /** @brief Expand current timeline clip (recover clips and tracks from an MLT playlist) */
+    void slotExpandClip();
+
 private slots:
     void slotRevert();
     /** @brief Open the project's backupdialog. */
@@ -120,6 +131,7 @@ private:
     QAction *m_fileRevert;
     KRecentFilesAction *m_recentFilesAction;
     NotesPlugin *m_notesPlugin;
+    QProgressDialog *m_progressDialog;
 };
 
 #endif
