@@ -83,7 +83,7 @@ void TransitionSettings::refreshIcons()
     for (int i = 0; i < allMenus.count(); i++) {
         QAction *m = allMenus.at(i);
         QIcon ic = m->icon();
-        if (ic.isNull()) continue;
+        if (ic.isNull() || ic.name().isEmpty()) continue;
         QIcon newIcon = KoIconUtils::themedIcon(ic.name());
         m->setIcon(newIcon);
     }
@@ -91,7 +91,7 @@ void TransitionSettings::refreshIcons()
     for (int i = 0; i < allButtons.count(); i++) {
         QToolButton *m = allButtons.at(i);
         QIcon ic = m->icon();
-        if (ic.isNull()) continue;
+        if (ic.isNull() || ic.name().isEmpty()) continue;
         QIcon newIcon = KoIconUtils::themedIcon(ic.name());
         m->setIcon(newIcon);
     }
