@@ -21,6 +21,7 @@
 #include "abstractclipitem.h"
 #include "customtrackscene.h"
 #include "kdenlivesettings.h"
+#include "customtrackview.h"
 
 #include <QDebug>
 #include <klocalizedstring.h>
@@ -120,9 +121,9 @@ void AbstractClipItem::setCropStart(const GenTime &pos)
     m_info.cropStart = pos;
 }
 
-void AbstractClipItem::updateItem()
+void AbstractClipItem::updateItem(int track)
 {
-    m_info.track = (int)(scenePos().y() / KdenliveSettings::trackheight());
+    m_info.track = track;
     m_info.startPos = GenTime((int) scenePos().x(), m_fps);
 }
 
@@ -527,6 +528,27 @@ void AbstractClipItem::mousePressEvent(QGraphicsSceneMouseEvent * event)
     }
 }
 
+// virtual
+void AbstractClipItem::mouseReleaseEvent(QGraphicsSceneMouseEvent * event)
+{
+    if (event->modifiers() & Qt::ControlModifier) {
+        // User want to do a rectangle selection, so ignore the event to pass it to the view
+        event->ignore();
+    } else {
+        QGraphicsItem::mouseReleaseEvent(event);
+    }
+}
+
+void AbstractClipItem::mouseMoveEvent(QGraphicsSceneMouseEvent * event)
+{
+    if (event->buttons() !=  Qt::LeftButton || event->modifiers() & Qt::ControlModifier) {
+        // User want to do a rectangle selection, so ignore the event to pass it to the view
+        event->ignore();
+    } else {
+        QGraphicsItem::mouseMoveEvent(event);
+    }
+}
+
 int AbstractClipItem::itemHeight()
 {
     return 0;
@@ -549,5 +571,25 @@ bool AbstractClipItem::isMainSelectedClip()
     return m_isMainSelectedClip;
 }
 
+int AbstractClipItem::trackForPos(int position)
+{
+    int track = 1;
+    if (!scene() || scene()->views().isEmpty()) return track;
+    CustomTrackView *view = static_cast<CustomTrackView*>(scene()->views()[0]);
+    if (view) {
+	track = view->getTrackFromPos(position);
+    }
+    return track;
+}
 
+int AbstractClipItem::posForTrack(int track)
+{
+    int pos = 0;
+    if (!scene() || scene()->views().isEmpty()) return pos;
+    CustomTrackView *view = static_cast<CustomTrackView*>(scene()->views()[0]);
+    if (view) {
+	pos = view->getPositionFromTrack(track) + 1;
+    }
+    return pos;
+}
 
