@@ -67,7 +67,7 @@ public:
     ItemInfo info() const;
     CustomTrackScene* projectScene();
     void updateRectGeometry();
-    void updateItem();
+    void updateItem(int track);
     void setItemLocked(bool locked);
     bool isItemLocked() const;
     void closeAnimation();
@@ -131,7 +131,10 @@ protected:
     void drawKeyFrames(QPainter *painter, const QTransform &transformation);
     int mouseOverKeyFrames(QPointF pos, double maxOffset);
     void mousePressEvent(QGraphicsSceneMouseEvent * event);
-
+    void mouseReleaseEvent(QGraphicsSceneMouseEvent * event);
+    void mouseMoveEvent(QGraphicsSceneMouseEvent * event);
+      int trackForPos(int position);
+      int posForTrack(int track);
 };
 
 #endif
