@@ -180,14 +180,46 @@ void AbstractGroupItem::paint(QPainter *p, const QStyleOptionGraphicsItem *optio
     p->drawRoundedRect(boundingRect().adjusted(0, 0, -1, 0), 3, 3);
 }
 
+int AbstractGroupItem::trackForPos(int position)
+{
+    int track = 1;
+    if (!scene() || scene()->views().isEmpty()) return track;
+    CustomTrackView *view = static_cast<CustomTrackView*>(scene()->views()[0]);
+    if (view) {
+	track = view->getTrackFromPos(position);
+    }
+    return track;
+}
+
+int AbstractGroupItem::posForTrack(int track)
+{
+    int pos = 0;
+    if (!scene() || scene()->views().isEmpty()) return pos;
+    CustomTrackView *view = static_cast<CustomTrackView*>(scene()->views()[0]);
+    if (view) {
+	pos = view->getPositionFromTrack(track);
+    }
+    return pos;
+}
+
 //virtual
 QVariant AbstractGroupItem::itemChange(GraphicsItemChange change, const QVariant &value)
 {
     if (change == QGraphicsItem::ItemSelectedChange) {
-        if (value.toBool()) setZValue(10);
+        if (value.toBool()) setZValue(3);
         else setZValue(1);
     }
-    if (change == ItemPositionChange && scene() && parentItem() == 0) {
+    CustomTrackScene *scene = NULL;
+    if (change == ItemPositionChange && parentItem() == 0) {
+        scene = projectScene();
+    }
+    if (scene) {
+        // calculate new position.
+        if (scene->isZooming) {
+            // For some reason, mouse wheel on selected itm sometimes triggered
+            // a position change event corrupting timeline, so discard it
+            return pos();
+        }
         // calculate new position.
         const int trackHeight = KdenliveSettings::trackheight();
         QPointF start = sceneBoundingRect().topLeft();
@@ -198,7 +230,8 @@ QVariant AbstractGroupItem::itemChange(GraphicsItemChange change, const QVariant
         ////qDebug()<<"GRP XPOS:"<<xpos<<", START:"<<start.x()<<",NEW:"<<newPos.x()<<"; SCENE:"<<scenePos().x()<<",POS:"<<pos().x();
         newPos.setX((int)(pos().x() + xpos - (int) start.x()));
         QStringList lockedTracks = property("locked_tracks").toStringList();
-        int proposedTrack = (property("y_absolute").toInt() + newPos.y()) / trackHeight;
+	
+        int proposedTrack = trackForPos(property("y_absolute").toInt() + newPos.y());
         // Check if top item is a clip or a transition
         int offset = 0;
         int topTrack = -1;
@@ -215,12 +248,12 @@ QVariant AbstractGroupItem::itemChange(GraphicsItemChange change, const QVariant
             }
             else continue;
             if (children.at(i)->type() == AVWidget) {
-                if (topTrack == -1 || currentTrack <= topTrack) {
+                if (topTrack == -1 || currentTrack >= topTrack) {
                     offset = 0;
                     topTrack = currentTrack;
                 }
             } else if (children.at(i)->type() == TransitionWidget) {
-                if (topTrack == -1 || currentTrack < topTrack) {
+                if (topTrack == -1 || currentTrack > topTrack) {
                     offset = (int)(trackHeight / 3 * 2 - 1);
                     topTrack = currentTrack;
                 }
@@ -235,12 +268,12 @@ QVariant AbstractGroupItem::itemChange(GraphicsItemChange change, const QVariant
                     }
                 }
                 if (clipGroup) {
-                    if (topTrack == -1 || currentTrack <= topTrack) {
+                    if (topTrack == -1 || currentTrack >= topTrack) {
                         offset = 0;
                         topTrack = currentTrack;
                     }
                 } else {
-                    if (topTrack == -1 || currentTrack < topTrack) {
+                    if (topTrack == -1 || currentTrack > topTrack) {
                         offset = (int)(trackHeight / 3 * 2 - 1);
                         topTrack = currentTrack;
                     }
@@ -248,15 +281,16 @@ QVariant AbstractGroupItem::itemChange(GraphicsItemChange change, const QVariant
             }
         }
         // Check no clip in the group goes outside of existing tracks
-        int maximumTrack = projectScene()->tracksCount() - 1;
+        int maximumTrack = projectScene()->tracksCount();
         int groupHeight = 0;
         for (int i = 0; i < groupTracks.count(); ++i) {
             int offset = groupTracks.at(i) - topTrack;
             if (offset > groupHeight) groupHeight = offset;
         }
+        
         maximumTrack -= groupHeight;
         proposedTrack = qMin(proposedTrack, maximumTrack);
-        proposedTrack = qMax(proposedTrack, 0);
+        proposedTrack = qMax(proposedTrack, groupTracks.count());
         int groupOffset = proposedTrack - topTrack;
         if (!lockedTracks.isEmpty()) {
             for (int i = 0; i < groupTracks.count(); ++i) {
@@ -265,7 +299,7 @@ QVariant AbstractGroupItem::itemChange(GraphicsItemChange change, const QVariant
                 }
             }
         }
-        newPos.setY((int)((proposedTrack) * trackHeight) + offset);
+        newPos.setY(posForTrack(proposedTrack) + offset);
         //if (newPos == start) return start;
 
         /*if (newPos.x() < 0) {
@@ -277,7 +311,7 @@ QVariant AbstractGroupItem::itemChange(GraphicsItemChange change, const QVariant
         QPainterPath shape;
         if (projectScene()->editMode() == NormalEdit) {
             shape = clipGroupShape(newPos - pos());
-            collidingItems = scene()->items(shape, Qt::IntersectsItemShape);
+            collidingItems = scene->items(shape, Qt::IntersectsItemShape);
             collidingItems.removeAll(this);
             for (int i = 0; i < children.count(); ++i) {
                 if (children.at(i)->type() == GroupWidget) {
@@ -315,7 +349,7 @@ QVariant AbstractGroupItem::itemChange(GraphicsItemChange change, const QVariant
                     newPos.setX(newPos.x() + offset);
                 }
                 // If there is still a collision after our position adjust, restore original pos
-                collidingItems = scene()->items(clipGroupShape(newPos - pos()), Qt::IntersectsItemShape);
+                collidingItems = scene->items(clipGroupShape(newPos - pos()), Qt::IntersectsItemShape);
                 collidingItems.removeAll(this);
                 for (int i = 0; i < children.count(); ++i) {
                     if (children.at(i)->type() == GroupWidget) {
@@ -333,7 +367,7 @@ QVariant AbstractGroupItem::itemChange(GraphicsItemChange change, const QVariant
 
         if (projectScene()->editMode() == NormalEdit) {
             shape = transitionGroupShape(newPos - pos());
-            collidingItems = scene()->items(shape, Qt::IntersectsItemShape);
+            collidingItems = scene->items(shape, Qt::IntersectsItemShape);
             collidingItems.removeAll(this);
             for (int i = 0; i < children.count(); ++i) {
                 if (children.at(i)->type() == GroupWidget) {
@@ -372,7 +406,7 @@ QVariant AbstractGroupItem::itemChange(GraphicsItemChange change, const QVariant
                     newPos.setX(newPos.x() + offset);
                 }
                 // If there is still a collision after our position adjust, restore original pos
-                collidingItems = scene()->items(transitionGroupShape(newPos - pos()), Qt::IntersectsItemShape);
+                collidingItems = scene->items(transitionGroupShape(newPos - pos()), Qt::IntersectsItemShape);
                 for (int i = 0; i < children.count(); ++i) {
                     collidingItems.removeAll(children.at(i));
                 }
@@ -436,6 +470,27 @@ void AbstractGroupItem::mousePressEvent(QGraphicsSceneMouseEvent * event)
     }
 }
 
+// virtual
+void AbstractGroupItem::mouseReleaseEvent(QGraphicsSceneMouseEvent * event)
+{
+    if (event->modifiers() & Qt::ControlModifier) {
+        // User want to do a rectangle selection, so ignore the event to pass it to the view
+        event->ignore();
+    } else {
+        QGraphicsItem::mouseReleaseEvent(event);
+    }
+}
+
+void AbstractGroupItem::mouseMoveEvent(QGraphicsSceneMouseEvent * event)
+{
+    if (event->buttons() !=  Qt::LeftButton || event->modifiers() & Qt::ControlModifier) {
+        // User want to do a rectangle selection, so ignore the event to pass it to the view
+        event->ignore();
+    } else {
+        QGraphicsItem::mouseMoveEvent(event);
+    }
+}
+
 void AbstractGroupItem::resizeStart(int diff)
 {
     bool info = false;
