@@ -24,6 +24,7 @@
 #include "clip.h"
 #include <mlt++/Mlt.h>
 
+
 Clip::Clip(Mlt::Producer &producer) : QObject(),
     m_producer(producer)
 {
@@ -54,20 +55,23 @@ void Clip::setProducer(Mlt::Producer& producer)
     m_producer = producer;
 }
 
-void Clip::addEffects(Mlt::Service& service)
+void Clip::addEffects(Mlt::Service& service, bool skipFades)
 {
     for (int ix = 0; ix < service.filter_count(); ++ix) {
         Mlt::Filter *effect = service.filter(ix);
         // Only duplicate Kdenlive filters, and skip the fade in effects
-        if (effect->is_valid()
-                && effect->get("kdenlive_id")
-                && strcmp(effect->get("kdenlive_id"), "fadein")
-                && strcmp(effect->get("kdenlive_id"), "fade_from_black")) {
+        if (effect->is_valid()) {
+	    QString effectId = effect->get("kdenlive_id");
+	    if (effectId.isEmpty() || (skipFades && (effectId == "fadein" || effectId == "fade_from_black"))) {
+		continue;
+	    }
             // no easy filter copy: do it by hand!
             Mlt::Filter *copy = new Mlt::Filter(*effect->profile(), effect->get("mlt_service"));
             if (copy && copy->is_valid()) {
-                for (int i = 0; 	i < effect->count(); ++i) {
-                    copy->set(effect->get_name(i), effect->get(i));
+                for (int i = 0; i < effect->count(); ++i) {
+                    QString paramName = effect->get_name(i);
+                    if (paramName.at(0) != '_')
+                        copy->set(effect->get_name(i), effect->get(i));
                 }
                 m_producer.attach(*copy);
             }
@@ -112,6 +116,26 @@ void Clip::deleteEffects()
     }
 }
 
+void Clip::disableEffects(bool disable)
+{
+    int ct = 0;
+    Mlt::Filter *filter = m_producer.filter(ct);
+    while (filter) {
+        QString ix = filter->get("kdenlive_ix");
+        if (!ix.isEmpty()) {
+            if (disable && filter->get_int("disable") == 0) {
+                filter->set("disable", 1);
+                filter->set("auto_disable", 1);
+            }
+            else if (!disable && filter->get_int("auto_disable") == 1) {
+                filter->set("disable", (char*) NULL);
+                filter->set("auto_disable", (char*) NULL);
+            }
+        }
+        ct++;
+        filter = m_producer.filter(ct);
+    }
+}
 
 QByteArray Clip::xml()
 {
@@ -132,3 +156,13 @@ QByteArray Clip::xml()
 Mlt::Producer *Clip::clone() {
     return new Mlt::Producer(*m_producer.profile(), "xml-string", xml().constData());
 }
+
+Mlt::Producer *Clip::softClone(const char*list) {
+    QString service = m_producer.get("mlt_service");
+    QString resource = m_producer.get("resource");
+    Mlt::Producer *clone = new Mlt::Producer(*m_producer.profile(), service.toUtf8().constData(), resource.toUtf8().constData());
+    Mlt::Properties original(m_producer.get_properties());
+    Mlt::Properties cloneProps(clone->get_properties());
+    cloneProps.pass_list(original, list);
+    return clone;
+}
