@@ -39,12 +39,18 @@ public:
     ~Clip();
     Clip& operator=(Clip& other);
     QByteArray xml();
+    /** @brief: Clone a producer (creates a completely independant copy). */
     Mlt::Producer *clone();
+    /** @brief: Clone a producer without using xml-string producer. 
+     *          When Movit is used, we must use this because xml-string crashes (probably attaches some normalizers) 
+     */
+    Mlt::Producer *softClone(const char*list);
     void deleteEffects();
-    void addEffects(Mlt::Service& service);
+    void addEffects(Mlt::Service& service, bool skipFades = false);
     void replaceEffects(Mlt::Service& service);
     void delEffect(int index);
-
+    /** @brief: Dis/enable all kdenlive effects on a clip. */
+    void disableEffects(bool disable);
     Mlt::Producer & producer();
 
 public Q_SLOTS:
