@@ -102,7 +102,8 @@ ClipItem::ClipItem(ProjectClip *clip, const ItemInfo& info, double fps, double s
         m_baseColor = m_binClip->getProducerColorProperty("resource");
     } else if (m_clipType == Image || m_clipType == Text) {
         m_baseColor = QColor(141, 166, 215);
-	m_startPix = m_binClip->thumbnail(rect().height(), frame_width);
+	m_startPix = m_binClip->thumbnail(frame_width, rect().height());
+        connect(m_binClip, SIGNAL(thumbUpdated(QImage)), this, SLOT(slotUpdateThumb(QImage)));
         //connect(m_clip->thumbProducer(), SIGNAL(thumbReady(int,QImage)), this, SLOT(slotThumbReady(int,QImage)));
     } else if (m_clipType == Audio) {
         m_baseColor = QColor(141, 215, 166);
@@ -428,6 +429,10 @@ QDomElement ClipItem::selectedEffect()
 
 void ClipItem::resetThumbs(bool clearExistingThumbs)
 {
+    if (m_clipType == Image || m_clipType || Text || m_clipType == Color || m_clipType == Audio) {
+        // These clip thumbnails are linked to bin thumbnail, not dynamic, nothing to do
+        return;
+    }
     if (clearExistingThumbs) {
         m_startPix = QPixmap();
         m_endPix = QPixmap();
@@ -458,7 +463,9 @@ void ClipItem::refreshClip(bool checkDuration, bool forceResetThumbs)
         m_baseColor = m_binClip->getProducerColorProperty("resource");
         m_paintColor = m_baseColor;
         update();
-    } else if (KdenliveSettings::videothumbnails()) resetThumbs(forceResetThumbs);
+    } else if (KdenliveSettings::videothumbnails()) {
+        resetThumbs(forceResetThumbs);
+    }
 }
 
 void ClipItem::slotFetchThumbs()
@@ -727,7 +734,7 @@ void ClipItem::paint(QPainter *painter,
         }
     }
     // draw audio thumbnails
-    if (KdenliveSettings::audiothumbnails() && m_speed == 1.0 && m_clipState != PlaylistState::VideoOnly && ((m_clipType == AV && (exposed.bottom() > (rect().height() / 2) || m_clipState == PlaylistState::AudioOnly)) || m_clipType == Audio) && m_audioThumbReady) {
+    if (KdenliveSettings::audiothumbnails() && m_speed == 1.0 && m_clipState != PlaylistState::VideoOnly && ((m_clipType == AV && (exposed.bottom() > (rect().height() / 2) || m_clipState == PlaylistState::AudioOnly)) || m_clipType == Audio) && m_audioThumbReady && !m_binClip->audioFrameCache.isEmpty()) {
         int startpixel = exposed.left();
         if (startpixel < 0)
             startpixel = 0;
@@ -2064,3 +2071,9 @@ void ClipItem::updateState(const QString &id)
     }
 }
 
+void ClipItem::slotUpdateThumb(QImage img)
+{
+    m_startPix = QPixmap::fromImage(img);
+    update();
+}
+
