@@ -60,11 +60,10 @@ CustomRuler::CustomRuler(const Timecode &tc, CustomTrackView *parent) :
         m_view(parent),
         m_duration(0),
         m_offset(0),
-        m_lastSeekPosition(SEEK_INACTIVE),
+        m_headPosition(SEEK_INACTIVE),
         m_clickedGuide(-1),
         m_rate(-1),
-        m_mouseMove(NO_MOVE),
-        m_cursorColor(palette().text())
+        m_mouseMove(NO_MOVE)
 {
     setFont(QFontDatabase::systemFont(QFontDatabase::SmallestReadableFont));
     QFontMetricsF fontMetrics(font());
@@ -80,8 +79,6 @@ CustomRuler::CustomRuler(const Timecode &tc, CustomTrackView *parent) :
     LITTLE_MARK_X = BIG_MARK_X + mark_length / 3;
     updateFrameSize();
     m_scale = 3;
-    m_zoneColor = KStatefulBrush(KColorScheme::View, KColorScheme::FocusColor, KSharedConfig::openConfig(KdenliveSettings::colortheme())).brush(this).color();
-    m_zoneColor.setAlpha(180);
     m_zoneStart = 0;
     m_zoneEnd = 100;
     m_contextMenu = new QMenu(this);
@@ -98,13 +95,6 @@ CustomRuler::CustomRuler(const Timecode &tc, CustomTrackView *parent) :
     setMouseTracking(true);
 }
 
-void CustomRuler::updatePalette()
-{
-    m_cursorColor = palette().text();
-    m_zoneColor = KStatefulBrush(KColorScheme::View, KColorScheme::FocusColor, KSharedConfig::openConfig(KdenliveSettings::colortheme())).brush(this).color();
-    m_zoneColor.setAlpha(180);
-}
-
 void CustomRuler::updateProjectFps(const Timecode &t)
 {
     m_timecode = t;
@@ -207,8 +197,13 @@ void CustomRuler::mouseMoveEvent(QMouseEvent * event)
                 } else return;
             }
             if (m_mouseMove == HORIZONTAL_MOVE) {
-		if (pos != m_lastSeekPosition && pos != m_view->cursorPos()) {
-		    m_view->seekCursorPos(pos);
+		if (pos != m_headPosition && pos != m_view->cursorPos()) {
+                    int x = m_headPosition == SEEK_INACTIVE ? pos : m_headPosition;
+                    m_headPosition = pos;
+                    int min = qMin(x, m_headPosition);
+                    int max = qMax(x, m_headPosition);
+                    update(min * m_factor - offset() - 3, BIG_MARK_X, (max - min) * m_factor + 6, MAX_HEIGHT - BIG_MARK_X);
+                    emit seekCursorPos(pos);
 		    m_view->slotCheckPositionScrolling();
 		}
             } else {
@@ -230,17 +225,9 @@ void CustomRuler::mouseMoveEvent(QMouseEvent * event)
 
     } else {
         int pos = (int)((event->x() + m_offset));
-	if (m_cursorColor == palette().text() && qAbs(pos - m_view->cursorPos() * m_factor) < 7) {
-	    // Mouse is over cursor
-	    m_cursorColor = palette().link();
-	    update(m_view->cursorPos() * m_factor - m_offset - 10, LABEL_SIZE + 2, 20, MAX_HEIGHT - LABEL_SIZE - 2);
-	}
-	else if (m_cursorColor == palette().link() && qAbs(pos - m_view->cursorPos() * m_factor) >= 7) {
-	    m_cursorColor = palette().text();
-	    update(m_view->cursorPos() * m_factor - m_offset - 10, LABEL_SIZE + 2, 20, MAX_HEIGHT - LABEL_SIZE - 2);
-	}
-	
-        if (event->y() <= 10) setCursor(Qt::ArrowCursor);
+        if (event->y() <= 10) {
+            setCursor(Qt::ArrowCursor);
+        }
         else if (qAbs(pos - m_zoneStart * m_factor) < 4) {
             setCursor(QCursor(Qt::SizeHorCursor));
             if (KdenliveSettings::frametimecode()) setToolTip(i18n("Zone start: %1", m_zoneStart));
@@ -262,15 +249,6 @@ void CustomRuler::mouseMoveEvent(QMouseEvent * event)
 }
 
 
-// virtual
-void CustomRuler::leaveEvent(QEvent * event)
-{
-    QWidget::leaveEvent(event);
-    if (m_cursorColor == palette().link()) {
-        m_cursorColor = palette().text();
-        update();
-    }
-}
 
 // virtual
 void CustomRuler::wheelEvent(QWheelEvent * e)
@@ -309,48 +287,33 @@ void CustomRuler::slotCursorMoved(int oldpos, int newpos)
 {
     int min = qMin(oldpos, newpos);
     int max = qMax(oldpos, newpos);
-    if (m_lastSeekPosition != SEEK_INACTIVE) {
-	if (m_lastSeekPosition == newpos) {
-	    m_lastSeekPosition = SEEK_INACTIVE;
-	}
-	else {
-	    min = qMin(min, m_lastSeekPosition);
-	    max = qMax(max, m_lastSeekPosition);
-	}
-    }
+    m_headPosition = newpos;
     update(min * m_factor - m_offset - FONT_WIDTH, BIG_MARK_X, (max - min) * m_factor + FONT_WIDTH * 2 + 2, MAX_HEIGHT - BIG_MARK_X);
 }
 
-void CustomRuler::updateRuler()
+void CustomRuler::updateRuler(int pos)
 {
-    // Update requested seek position
-    int min = SEEK_INACTIVE;
-    int max = SEEK_INACTIVE;
-    if (m_lastSeekPosition != SEEK_INACTIVE) {
-	min = max = m_lastSeekPosition;
-    }
-    m_lastSeekPosition = m_view->seekPosition();
-    if (m_lastSeekPosition != SEEK_INACTIVE) {
-	if (min == SEEK_INACTIVE) {
-	    min = max = m_lastSeekPosition;
-	}
-	else {
-	    min = qMin(min, m_lastSeekPosition);
-	    max = qMax(max, m_lastSeekPosition);
-	}
-    }
-    if (min != SEEK_INACTIVE) {
-	update(min * m_factor - offset() - 3, BIG_MARK_X, (max - min) * m_factor + 6, MAX_HEIGHT - BIG_MARK_X);
-    }
+    int x = m_headPosition;
+    m_headPosition = pos;
+    if (x == SEEK_INACTIVE) x = pos;
+    int min = qMin(x, m_headPosition);
+    int max = qMax(x, m_headPosition);
+    update(min * m_factor - offset() - 3, BIG_MARK_X, (max - min) * m_factor + 6, MAX_HEIGHT - BIG_MARK_X);
 }
 
 void CustomRuler::setPixelPerMark(int rate)
 {
+    if (rate == m_rate) return;
     int scale = comboScale[rate];
     m_rate = rate;
     m_factor = 1.0 / (double) scale * FRAME_SIZE;
     m_scale = 1.0 / (double) scale;
     double fend = m_scale * littleMarkDistance;
+    int textFactor = 1;
+    int timeLabelSize = QWidget::fontMetrics().boundingRect("00:00:00:000").width();
+    if (timeLabelSize > littleMarkDistance) {
+        textFactor = timeLabelSize / littleMarkDistance + 1;
+    }
     if (rate > 8) {
         mediumMarkDistance = (double) FRAME_SIZE * m_timecode.fps() * 60;
         bigMarkDistance = (double) FRAME_SIZE * m_timecode.fps() * 300;
@@ -364,41 +327,52 @@ void CustomRuler::setPixelPerMark(int rate)
         mediumMarkDistance = (double) FRAME_SIZE * m_timecode.fps();
         bigMarkDistance = (double) FRAME_SIZE * m_timecode.fps() * 60;
     }
-    switch (rate) {
-    case 0:
-        m_textSpacing = fend;
-        break;
-    case 1:
-        m_textSpacing = fend * 5;
-        break;
-    case 2:
-    case 3:
-    case 4:
-        m_textSpacing = fend * m_timecode.fps();
-        break;
-    case 5:
-        m_textSpacing = fend * m_timecode.fps() * 5;
-        break;
-    case 6:
-        m_textSpacing = fend * m_timecode.fps() * 10;
-        break;
-    case 7:
-        m_textSpacing = fend * m_timecode.fps() * 30;
-        break;
-    case 8:
-    case 9:
-        m_textSpacing = fend * m_timecode.fps() * 40;
-        break;
-    case 10:
-        m_textSpacing = fend * m_timecode.fps() * 80;
-        break;
-    case 11:
-    case 12:
-        m_textSpacing = fend * m_timecode.fps() * 400;
-        break;
-    case 13:
-        m_textSpacing = fend * m_timecode.fps() * 800;
-        break;
+
+    m_textSpacing = fend * textFactor;
+    
+    if (m_textSpacing < timeLabelSize) {
+        int roundedFps = (int) (m_timecode.fps() + 0.5);
+        int factor = timeLabelSize / m_textSpacing;
+        if (factor < 2) {
+            m_textSpacing *= 2;
+        }
+        else if (factor < 5) {
+            m_textSpacing *= 5;
+        }
+        else if (factor < 10) {
+            m_textSpacing *= 10;
+        }
+        else if (factor < roundedFps) {
+            m_textSpacing *= roundedFps;
+        }
+        else if (factor < 2 * roundedFps) {
+            m_textSpacing *= 2 * roundedFps;
+        }
+        else if (factor < 5 * roundedFps) {
+            m_textSpacing *= 5 * roundedFps;
+        }
+        else if (factor < 10 * roundedFps) {
+            m_textSpacing *= 10 * roundedFps;
+        }
+        else if (factor < 20 * roundedFps) {
+            m_textSpacing *= 20 * roundedFps;
+        }
+        else if (factor < 60 * roundedFps) {
+            m_textSpacing *= 60 * roundedFps;
+        }
+        else if (factor < 120 * roundedFps) {
+            m_textSpacing *= 120 * roundedFps;
+        }
+        else if (factor < 150 * roundedFps) {
+            m_textSpacing *= 150 * roundedFps;
+        }
+        else if (factor < 300 * roundedFps) {
+            m_textSpacing *= 300 * roundedFps;
+        }
+        else {
+            factor /= (300 * roundedFps);
+            m_textSpacing *= (factor + 1) * (300 * roundedFps);
+        }
     }
     update();
 }
@@ -416,18 +390,18 @@ void CustomRuler::paintEvent(QPaintEvent *e)
     QStylePainter p(this);
     const QRect &paintRect = e->rect();
     p.setClipRect(paintRect);
+    p.fillRect(paintRect, palette().midlight().color());
 
     // Draw zone background
     const int zoneStart = (int)(m_zoneStart * m_factor);
     const int zoneEnd = (int)(m_zoneEnd * m_factor);
-    p.fillRect(zoneStart - m_offset, LABEL_SIZE + 2, zoneEnd - zoneStart, MAX_HEIGHT - LABEL_SIZE - 2, m_zoneColor);
-    
+    p.fillRect(zoneStart - m_offset, LABEL_SIZE + 2, zoneEnd - zoneStart, MAX_HEIGHT - LABEL_SIZE - 2, palette().color(QPalette::Highlight));
+
     double f, fend;
     const int offsetmax = ((paintRect.right() + m_offset) / FRAME_SIZE + 1) * FRAME_SIZE;
     int offsetmin;
 
     p.setPen(palette().text().color());
-
     // draw time labels
     if (paintRect.y() < LABEL_SIZE) {
         offsetmin = (paintRect.left() + m_offset) / m_textSpacing;
@@ -447,8 +421,11 @@ void CustomRuler::paintEvent(QPaintEvent *e)
     // draw the little marks
     fend = m_scale * littleMarkDistance;
     if (fend > 5) {
-        for (f = offsetmin - m_offset; f < offsetmax - m_offset; f += fend)
-            p.drawLine((int)f, LITTLE_MARK_X, (int)f, MAX_HEIGHT);
+        QLineF l(offsetmin - m_offset, LITTLE_MARK_X, offsetmin - m_offset, MAX_HEIGHT);
+        for (f = offsetmin; f < offsetmax; f += fend) {
+            l.translate(fend, 0);
+            p.drawLine(l);
+        }
     }
 
     offsetmin = (paintRect.left() + m_offset) / mediumMarkDistance;
@@ -456,8 +433,11 @@ void CustomRuler::paintEvent(QPaintEvent *e)
     // draw medium marks
     fend = m_scale * mediumMarkDistance;
     if (fend > 5) {
-        for (f = offsetmin - m_offset - fend; f < offsetmax - m_offset + fend; f += fend)
-            p.drawLine((int)f, MIDDLE_MARK_X, (int)f, MAX_HEIGHT);
+        QLineF l(offsetmin - m_offset - fend, MIDDLE_MARK_X, offsetmin - m_offset - fend, MAX_HEIGHT);
+        for (f = offsetmin - fend; f < offsetmax + fend; f += fend) {
+            l.translate(fend, 0);
+            p.drawLine(l);
+        }
     }
 
     offsetmin = (paintRect.left() + m_offset) / bigMarkDistance;
@@ -465,8 +445,11 @@ void CustomRuler::paintEvent(QPaintEvent *e)
     // draw big marks
     fend = m_scale * bigMarkDistance;
     if (fend > 5) {
-        for (f = offsetmin - m_offset; f < offsetmax - m_offset; f += fend)
-            p.drawLine((int)f, BIG_MARK_X, (int)f, MAX_HEIGHT);
+        QLineF l(offsetmin - m_offset, BIG_MARK_X, offsetmin - m_offset, MAX_HEIGHT);
+        for (f = offsetmin; f < offsetmax; f += fend) {
+            l.translate(fend, 0);
+            p.drawLine(l);
+        }
     }
 
     // draw zone cursors
@@ -492,12 +475,14 @@ void CustomRuler::paintEvent(QPaintEvent *e)
     const int value  =  m_view->cursorPos() * m_factor - m_offset;
     QPolygon pa(3);
     pa.setPoints(3, value - FONT_WIDTH, LABEL_SIZE + 3, value + FONT_WIDTH, LABEL_SIZE + 3, value, MAX_HEIGHT);
-    p.setBrush(m_cursorColor);
+    p.setBrush(palette().brush(QPalette::Text));
     p.setPen(Qt::NoPen);
     p.drawPolygon(pa);
-    
-    if (m_lastSeekPosition != SEEK_INACTIVE && m_lastSeekPosition != m_view->cursorPos()) {
-	p.fillRect(m_lastSeekPosition * m_factor - m_offset - 1, BIG_MARK_X + 1, 3, MAX_HEIGHT - BIG_MARK_X - 1, palette().linkVisited());
+    if (m_headPosition == m_view->cursorPos()) {
+        m_headPosition = SEEK_INACTIVE;
+    }
+    if (m_headPosition != SEEK_INACTIVE) {
+	p.fillRect(m_headPosition * m_factor - m_offset - 1, BIG_MARK_X + 1, 3, MAX_HEIGHT - BIG_MARK_X - 1, palette().linkVisited());
     }
 
 }
