@@ -19,8 +19,9 @@
 
 
 #include "headertrack.h"
-
+#include "track.h"
 #include "kdenlivesettings.h"
+#include "utils/KoIconUtils.h"
 #include "effectslist/effectslist.h"
 
 #include <klocalizedstring.h>
@@ -35,15 +36,16 @@
 #include <QDomDocument>
 #include <QMimeData>
 
-HeaderTrack::HeaderTrack(int index, TrackInfo info, int height, const QList <QAction *> &actions, QWidget *parent) :
-        QWidget(parent),
-        m_index(index),
+HeaderTrack::HeaderTrack(TrackInfo info, const QList <QAction *> &actions, Track *parent, QWidget *parentWidget) :
+        QWidget(parentWidget),
         m_type(info.type),
-        m_isSelected(false)
+        m_parentTrack(parent),
+        m_isSelected(false),
+        m_switchComposite(NULL),
+        m_switchVideo(NULL)
 {
-    setFixedHeight(height);
     setupUi(this);
-    m_name = info.trackName.isEmpty() ? QString::number(m_index) : info.trackName;
+    m_name = info.trackName.isEmpty() ? QString::number(m_parentTrack->index()) : info.trackName;
     QFontMetrics metrics(font());
     m_tb = new QToolBar(this);
     m_tb->setToolButtonStyle(Qt::ToolButtonIconOnly);
@@ -54,21 +56,22 @@ HeaderTrack::HeaderTrack(int index, TrackInfo info, int height, const QList <QAc
     QSize s(iconSize, iconSize);
     //setMinimumWidth(qMax(metrics.boundingRect(m_name).width() + iconSize + contentsMargins().right() * 6, 5 * iconSize));
     track_number->setText(m_name);
+    track_number->setContextMenuPolicy(Qt::NoContextMenu);
+    track_number->installEventFilter(this);
     connect(track_number, SIGNAL(editingFinished()), this, SLOT(slotRenameTrack()));
-    effect_label->setPixmap(QIcon::fromTheme("kdenlive-track_has_effect").pixmap(s));
+    effect_label->setPixmap(KoIconUtils::themedIcon("kdenlive-track_has_effect").pixmap(s));
     updateEffectLabel(info.effectsList.effectNames());
     setAcceptDrops(true);
     button_layout->addWidget(m_tb);
     m_switchLock = new KDualAction(i18n("Lock track"), i18n("Unlock track"), this);
-    m_switchLock->setActiveIcon(QIcon::fromTheme("kdenlive-lock"));
-    m_switchLock->setInactiveIcon(QIcon::fromTheme("kdenlive-unlock"));
+    m_switchLock->setActiveIcon(KoIconUtils::themedIcon("kdenlive-lock"));
+    m_switchLock->setInactiveIcon(KoIconUtils::themedIcon("kdenlive-unlock"));
     m_switchLock->setActive(info.isLocked);
     connect(m_switchLock, SIGNAL(activeChanged(bool)), this, SLOT(switchLock(bool)));
     m_tb->addAction(m_switchLock);
-    
     m_switchAudio = new KDualAction(i18n("Disable audio"), i18n("Enable audio"), this);
-    m_switchAudio->setActiveIcon(QIcon::fromTheme("kdenlive-hide-audio-effects"));
-    m_switchAudio->setInactiveIcon(QIcon::fromTheme("kdenlive-show-audio-effects"));
+    m_switchAudio->setActiveIcon(KoIconUtils::themedIcon("kdenlive-hide-audio"));
+    m_switchAudio->setInactiveIcon(KoIconUtils::themedIcon("kdenlive-show-audio"));
     m_switchAudio->setActive(info.isMute);
     connect(m_switchAudio, SIGNAL(activeChanged(bool)), this, SLOT(switchAudio(bool)));
     m_tb->addAction(m_switchAudio);
@@ -76,29 +79,59 @@ HeaderTrack::HeaderTrack(int index, TrackInfo info, int height, const QList <QAc
     if (m_type == VideoTrack) {
         setBackgroundRole(QPalette::AlternateBase);
         setAutoFillBackground(true);
-	m_switchVideo = new KDualAction(i18n("Disable video"), i18n("Enable video"), this);
-	m_switchVideo->setActiveIcon(QIcon::fromTheme("kdenlive-hide-video-effects"));
-	m_switchVideo->setInactiveIcon(QIcon::fromTheme("kdenlive-show-video-effects"));
-	m_switchVideo->setActive(info.isBlind);
-	connect(m_switchVideo, SIGNAL(activeChanged(bool)), this, SLOT(switchVideo(bool)));
-	m_tb->addAction(m_switchVideo);
-    } else m_switchVideo = NULL;
+        m_switchVideo = new KDualAction(i18n("Disable video"), i18n("Enable video"), this);
+        m_switchVideo->setActiveIcon(KoIconUtils::themedIcon("kdenlive-hide-video"));
+        m_switchVideo->setInactiveIcon(KoIconUtils::themedIcon("kdenlive-show-video"));
+        m_switchVideo->setActive(info.isBlind);
+        connect(m_switchVideo, SIGNAL(activeChanged(bool)), this, SLOT(switchVideo(bool)));
+        m_tb->addAction(m_switchVideo);
 
-    // Don't show track buttons if size is too small
-    if (height < 3 * iconSize) {
-        m_tb->setHidden(true);
-        //horizontalSpacer;
+        m_switchComposite = new KDualAction(i18n("Opaque"), i18n("Composite"), this);
+        m_switchComposite->setActiveIcon(KoIconUtils::themedIcon("kdenlive-composite"));
+        m_switchComposite->setInactiveIcon(KoIconUtils::themedIcon("kdenlive-no-composite"));
+        m_switchComposite->setActive(info.composite);
+        connect(m_switchComposite, &KDualAction::activeChangedByUser, this, &HeaderTrack::switchComposite);
+        m_tb->addAction(m_switchComposite);
+    } else {
+        m_switchVideo = NULL;
+        m_switchComposite = NULL;
     }
 
+    updateStatus(info);
     //TODO: this resizing stuff should'nt be necessary
-    setMinimumWidth(m_tb->widgetForAction(m_switchLock)->width() * 1.1);
+    setMinimumWidth(m_tb->widgetForAction(m_switchLock)->width() * 1.5);
     setContextMenuPolicy(Qt::ActionsContextMenu);
     addActions(actions);
 }
 
-/*HeaderTrack::~HeaderTrack()
+
+HeaderTrack::~HeaderTrack()
 {
-}*/
+    //qDebug()<<" - --DEL TK HEAD: "<<m_name;
+}
+
+bool HeaderTrack::eventFilter(QObject *obj, QEvent *event)
+{
+    if (event->type() == QEvent::MouseButtonPress) {
+        // Make sure to select current track when clicking in track name widget
+        emit selectTrack(m_parentTrack->index());
+    }
+    return QWidget::eventFilter(obj, event);
+}
+
+
+void HeaderTrack::updateStatus(TrackInfo info)
+{
+    m_switchAudio->setActive(info.isMute);
+    if (m_switchVideo) m_switchVideo->setActive(info.isBlind);
+    if (m_switchComposite) m_switchComposite->setActive(info.composite);
+    m_switchLock->setActive(info.isLocked);
+}
+
+void HeaderTrack::setTrackHeight(int height)
+{
+    setFixedHeight(height);
+}
 
 void HeaderTrack::updateEffectLabel(const QStringList &effects)
 {
@@ -116,10 +149,8 @@ void HeaderTrack::mousePressEvent(QMouseEvent * event)
 {
     if (track_number->hasFocus()) {
         track_number->clearFocus();
-        return;
     }
-    if (!m_isSelected) emit selectTrack(m_index);
-    emit showTrackEffects(m_index);
+    emit selectTrack(m_parentTrack->index());
     QWidget::mousePressEvent(event);
 }
 
@@ -127,9 +158,8 @@ void HeaderTrack::mouseDoubleClickEvent(QMouseEvent* event)
 {
     if (track_number->hasFocus()) {
         track_number->clearFocus();
-        return;
     }
-    emit configTrack(m_index);
+    emit configTrack();
     QWidget::mouseDoubleClickEvent(event);
 }
 
@@ -150,8 +180,8 @@ void HeaderTrack::dropEvent(QDropEvent * event)
         // single effect dropped
         e.removeAttribute("kdenlive_ix");
     }
-    emit selectTrack(m_index);
-    emit addTrackEffect(e, m_index);
+    emit selectTrack(m_parentTrack->index());
+    emit addTrackEffect(e, m_parentTrack->index());
     /*if (scene() && !scene()->views().isEmpty()) {
         event->accept();
         CustomTrackView *view = (CustomTrackView *) scene()->views()[0];
@@ -178,9 +208,9 @@ void HeaderTrack::dragEnterEvent(QDragEnterEvent *event)
 
 void HeaderTrack::setSelectedIndex(int ix)
 {
-    if (m_index == ix) {
+    if (m_parentTrack->index() == ix) {
         m_isSelected = true;
-        setBackgroundRole(QPalette::Button);
+        setBackgroundRole(QPalette::Mid);
         setAutoFillBackground(true);
     } else if (m_type != VideoTrack) {
         m_isSelected = false;
@@ -200,19 +230,24 @@ void HeaderTrack::adjustSize(int height)
     setFixedHeight(height);
 }
 
+void HeaderTrack::switchComposite(bool enable)
+{
+    emit switchTrackComposite(m_parentTrack->index(), !enable);
+}
+
 void HeaderTrack::switchVideo(bool enable)
 {
-    emit switchTrackVideo(m_index, enable);
+    emit switchTrackVideo(m_parentTrack->index(), enable);
 }
 
 void HeaderTrack::switchAudio(bool enable)
 {
-    emit switchTrackAudio(m_index, enable);
+    emit switchTrackAudio(m_parentTrack->index(), enable);
 }
 
 void HeaderTrack::switchLock(bool enable)
 {
-    emit switchTrackLock(m_index, enable);
+    emit switchTrackLock(m_parentTrack->index(), enable);
 }
 
 void HeaderTrack::setLock(bool lock)
@@ -220,11 +255,26 @@ void HeaderTrack::setLock(bool lock)
     m_switchLock->setActive(lock);
 }
 
+void HeaderTrack::disableComposite()
+{
+    if (m_switchComposite) {
+        m_switchComposite->setVisible(false);
+    }
+}
+
+void HeaderTrack::setComposite(bool enable)
+{
+    if (m_switchComposite) {
+        m_switchComposite->setActive(enable);
+    }
+    else qDebug()<<" / / /ERROR; TRYING TO EDIT COMPOSITE ON AUDIO TRACK: "<<m_parentTrack->index();
+}
+
 void HeaderTrack::slotRenameTrack()
 {
     track_number->clearFocus();
     if (m_name != track_number->text())
-        emit renameTrack(m_index, track_number->text());
+        emit renameTrack(m_parentTrack->index(), track_number->text());
 }
 
 void HeaderTrack::renameTrack(const QString &name)
@@ -233,6 +283,11 @@ void HeaderTrack::renameTrack(const QString &name)
     track_number->setText(name);
 }
 
+QString HeaderTrack::name() const
+{
+    return m_name;
+}
+
 
 
 
