@@ -283,7 +283,7 @@ int Timeline::getTracks() {
                 getEffects(playlist, NULL, i);
                 slotUpdateTrackEffectState(i);
             }
-            connect(tk, &Track::newTrackDuration, this, &Timeline::checkDuration);
+            connect(tk, &Track::newTrackDuration, this, &Timeline::checkDuration, Qt::DirectConnection);
             connect(tk, SIGNAL(storeSlowMotion(QString,Mlt::Producer *)), m_doc->renderer(), SLOT(storeSlowmotionProducer(QString,Mlt::Producer *)));
         }
     }
@@ -388,8 +388,8 @@ void Timeline::getTransitions() {
             }
             Transition *tr = new Transition(transitionInfo, a_track, m_doc->fps(), base, QString(prop.get("automatic")) == "1");
             tr->setPos(transitionInfo.startPos.frames(m_doc->fps()), KdenliveSettings::trackheight() * (visibleTracksCount() - transitionInfo.track) + 1 + tr->itemOffset());
-            if (QString(prop.get("force_track")) == "1") tr->setForcedTrack(true, a_track);
-            if (isTrackLocked(b_track - 1)) tr->setItemLocked(true);
+            if (QString(prop.get("force_track")) == QLatin1String("1")) tr->setForcedTrack(true, a_track);
+            if (isTrackLocked(b_track)) tr->setItemLocked(true);
             m_scene->addItem(tr);
             service = mlt_service_producer(service);
         }
@@ -812,7 +812,8 @@ void Timeline::updatePalette()
     p.setColor(QPalette::Button, norm);
     QColor col = scheme.background().color();
     QColor col2 = scheme.foreground().color();
-    headers_container->setStyleSheet(QString("QLineEdit { background-color: transparent;color: %1;} QLineEdit:hover{ background-color: %2;} QLineEdit:focus { background-color: %2;}").arg(col2.name()).arg(col.name()));
+    headers_container->setStyleSheet(QStringLiteral("QLineEdit { background-color: transparent;color: %1;} QLineEdit:hover{ background-color: %2;} QLineEdit:focus { background-color: %2;}").arg(col2.name()).arg(col.name()));
+    m_trackview->updatePalette();
 }
 
 void Timeline::refreshIcons()
@@ -821,7 +822,7 @@ void Timeline::refreshIcons()
     for (int i = 0; i < allMenus.count(); i++) {
         QAction *m = allMenus.at(i);
         QIcon ic = m->icon();
-        if (ic.isNull()) continue;
+        if (ic.isNull() || ic.name().isEmpty()) continue;
         QIcon newIcon = KoIconUtils::themedIcon(ic.name());
         m->setIcon(newIcon);
     }
@@ -829,11 +830,11 @@ void Timeline::refreshIcons()
     for (int i = 0; i < allButtons.count(); i++) {
         KDualAction *m = allButtons.at(i);
         QIcon ic = m->activeIcon();
-        if (ic.isNull()) continue;
+        if (ic.isNull() || ic.name().isEmpty()) continue;
         QIcon newIcon = KoIconUtils::themedIcon(ic.name());
         m->setActiveIcon(newIcon);
         ic = m->inactiveIcon();
-        if (ic.isNull()) continue;
+        if (ic.isNull() || ic.name().isEmpty()) continue;
         newIcon = KoIconUtils::themedIcon(ic.name());
         m->setInactiveIcon(newIcon);
     }
