@@ -191,6 +191,7 @@ bool Track::resize(qreal t, qreal dt, bool end)
     QScopedPointer<Mlt::Producer> clip(m_playlist.get_clip(index));
     if (clip == NULL || clip->is_blank()) {
         qWarning("Can't resize clip at %f", t);
+	m_playlist.unlock();
         return false;
     }
 
@@ -241,6 +242,7 @@ bool Track::resize(qreal t, qreal dt, bool end)
             }
         }
     }
+    
     m_playlist.consolidate_blanks();
     m_playlist.unlock();
     return true;
@@ -382,8 +384,7 @@ bool Track::replaceAll(const QString &id, Mlt::Producer *original, Mlt::Producer
             cut = videoOnlyProducer->cut(p->get_in(), p->get_out());
         }
         if (cut) {
-            // We do not re-add effects here, since we cutted the effects are taken from original
-            //Clip(*cut).addEffects(*p);
+            Clip(*cut).addEffects(*p);
             m_playlist.remove(i);
             m_playlist.insert(*cut, i);
             m_playlist.consolidate_blanks();
