@@ -39,8 +39,6 @@ Transition::Transition(const ItemInfo &info, int transitiontrack, double fps, co
 {
     setZValue(4);
     m_info.cropDuration = info.endPos - info.startPos;
-    setPos(info.startPos.frames(fps), (int)(info.track * KdenliveSettings::trackheight() + itemOffset() + 1));
-
     if (QApplication::style()->styleHint(QStyle::SH_Widget_Animate, 0, QApplication::activeWindow())) {
         // animation disabled
         setRect(0, 0, m_info.cropDuration.frames(fps) - 0.02, (qreal) itemHeight());
@@ -222,15 +220,17 @@ QVariant Transition::itemChange(GraphicsItemChange change, const QVariant &value
         int xpos = projectScene()->getSnapPointForPos((int) newPos.x(), KdenliveSettings::snaptopoints());
         xpos = qMax(xpos, 0);
         newPos.setX(xpos);
-        int newTrack = newPos.y() / KdenliveSettings::trackheight();
-        newTrack = qMin(newTrack, projectScene()->tracksCount() - 1);
-        newTrack = qMax(newTrack, 0);
+        int newTrack = trackForPos(newPos.y());
         QStringList lockedTracks = property("locked_tracks").toStringList();
         if (lockedTracks.contains(QString::number(newTrack))) {
             // Trying to move to a locked track
             return pos();
         }
-        newPos.setY((int)(newTrack * KdenliveSettings::trackheight() + itemOffset() + 1));
+        int maximumTrack = projectScene()->tracksCount();
+        newTrack = qMin(newTrack, maximumTrack);
+        newTrack = qMax(newTrack, 0);
+        newPos.setY(posForTrack(newTrack) + itemOffset());
+
         // Only one clip is moving
         QRectF sceneShape = rect();
         sceneShape.translate(newPos);
@@ -348,7 +348,7 @@ int Transition::defaultZValue() const
     return 3;
 }
 
-bool Transition::updateKeyframes(int oldEnd)
+bool Transition::updateKeyframes(ItemInfo oldInfo, ItemInfo newInfo)
 {
     QString keyframes;
     QDomElement pa;
@@ -362,7 +362,8 @@ bool Transition::updateKeyframes(int oldEnd)
         }
     }
     if (keyframes.isEmpty()) return false;
-    int duration = cropDuration().frames(m_fps) - 1;
+    int duration = newInfo.cropDuration.frames(m_fps) - 1;
+    int oldEnd = oldInfo.cropDuration.frames(m_fps) - 1;
     QStringList values = keyframes.split(';');
     int frame;
     int i = 0;
@@ -384,7 +385,7 @@ bool Transition::updateKeyframes(int oldEnd)
         }
         return false;
     }
-    else {
+    else if (oldEnd > duration) {
         // Transition was shortened, check for out of bounds keyframes
         foreach(const QString &pos, values) {
             if (!pos.contains('=')) {
@@ -426,7 +427,6 @@ bool Transition::updateKeyframes(int oldEnd)
         }
         pa.setAttribute("value", values.join(";"));
     }
-    
     return true;
 }
 
