@@ -32,7 +32,11 @@
 #include <kio/storedtransferjob.h>
 #include <KLocalizedString>
 #include <KMessageBox>
-
+/**
+ * @brief FreeSound::FreeSound
+ * @param listWidget
+ * @param parent
+ */
 FreeSound::FreeSound(QListWidget *listWidget, QObject *parent) :
         AbstractService(listWidget, parent),
         m_previewProcess(new QProcess)
@@ -40,34 +44,41 @@ FreeSound::FreeSound(QListWidget *listWidget, QObject *parent) :
     serviceType = FREESOUND;
     hasPreview = true;
     hasMetadata = true;
+    connect (m_previewProcess ,SIGNAL (finished(int , QProcess::ExitStatus )),this,SLOT(slotPreviewFinished(int , QProcess::ExitStatus)));
 }
 
 FreeSound::~FreeSound()
 {
     delete m_previewProcess;
 }
-
+/**
+ * @brief FreeSound::slotStartSearch
+ * @param searchText
+ * @param page
+ */
 void FreeSound::slotStartSearch(const QString &searchText, int page)
 {
+    // ver  2 of freesound API
     m_listWidget->clear();
-    QString uri = "http://www.freesound.org/api/sounds/search/?q=";
+    QString uri = "http://www.freesound.org/apiv2/search/text/?format=json&query=";
     uri.append(searchText);
     if (page > 1)
-        uri.append("&p=" + QString::number(page));
-    uri.append("&api_key=a1772c8236e945a4bee30a64058dabf8");
-
+        uri.append("&page=" + QString::number(page));
+    uri.append("&token=441d88374716e7a3503997151e4780566f007313");
     
     KIO::StoredTransferJob* resolveJob = KIO::storedGet( QUrl(uri), KIO::NoReload, KIO::HideProgressInfo );
     connect(resolveJob, &KIO::StoredTransferJob::result, this, &FreeSound::slotShowResults);
 }
 
-
+/**
+ * @brief FreeSound::slotShowResults
+ * @param job
+ */
 void FreeSound::slotShowResults(KJob* job)
 {
     if (job->error() != 0 ) return;
     m_listWidget->blockSignals(true);
     KIO::StoredTransferJob* storedQueryJob = static_cast<KIO::StoredTransferJob*>( job );
-    ////qDebug()<<"// GOT RESULT: "<<m_result;
     QJsonParseError jsonError;
     QJsonDocument doc = QJsonDocument::fromJson(storedQueryJob->data(), &jsonError);
     if (jsonError.error != QJsonParseError::NoError) {
@@ -81,19 +92,20 @@ void FreeSound::slotShowResults(KJob* job)
         QMap <QString, QVariant> map = data.toMap();
         QMap<QString, QVariant>::const_iterator i = map.constBegin();
         while (i != map.constEnd()) {
-            if (i.key() == "num_results") emit searchInfo(i18np("Found %1 result", "Found %1 results", i.value().toInt()));
+            if (i.key() == "count") emit searchInfo(i18np("Found %1 result", "Found %1 results", i.value().toInt()));
             else if (i.key() == "num_pages") {
                 emit maxPages(i.value().toInt());
             }
-            else if (i.key() == "sounds") {
+            else if (i.key() == "results") {
                 sounds = i.value();
                 if (sounds.canConvert(QVariant::List)) {
                     QList <QVariant> soundsList = sounds.toList();
                     for (int j = 0; j < soundsList.count(); ++j) {
                         if (soundsList.at(j).canConvert(QVariant::Map)) {
                             QMap <QString, QVariant> soundmap = soundsList.at(j).toMap();
-                            if (soundmap.contains("original_filename")) {
-                                QListWidgetItem *item = new   QListWidgetItem(soundmap.value("original_filename").toString(), m_listWidget);
+                            if (soundmap.contains("name")) {
+                                QListWidgetItem *item = new   QListWidgetItem(soundmap.value("name").toString(), m_listWidget);
+                                /* in v2 of API we do not have these items in the json
                                 item->setData(imageRole, soundmap.value("waveform_m").toString());
                                 item->setData(infoUrl, soundmap.value("url").toString());
                                 item->setData(infoData, soundmap.value("ref").toString() + "?api_key=a1772c8236e945a4bee30a64058dabf8");
@@ -101,14 +113,17 @@ void FreeSound::slotShowResults(KJob* job)
                                 item->setData(idRole, soundmap.value("id").toInt());
                                 item->setData(previewRole, soundmap.value("preview-hq-mp3").toString());
                                 item->setData(downloadRole, soundmap.value("serve").toString() + "?api_key=a1772c8236e945a4bee30a64058dabf8");
-                                QVariant authorInfo = soundmap.value("user");
-                                if (authorInfo.canConvert(QVariant::Map)) {
-                                    QMap <QString, QVariant> authorMap = authorInfo.toMap();
-                                    if (authorMap.contains("username")) {
-                                        item->setData(authorRole, authorMap.value("username").toString());
-                                        item->setData(authorUrl, authorMap.value("url").toString());
-                                    }
-                                }
+                                */
+                                QVariant vid = soundmap.value("id");
+                                item->setData(idRole, vid);
+
+                                QVariant authorInfo = soundmap.value("username");
+                                item->setData(authorRole, authorInfo);
+                                // item->setData(authorUrl, authorMap.value("url").toString());
+                                item->setData(authorUrl, "http://freesound.org/people/" + soundmap.value("username").toString());
+                                item->setData(licenseRole, soundmap.value("license"));
+                                item->setData(infoData,"http://www.freesound.org/apiv2/sounds/"+ vid.toString() +"/?format=json&token=441d88374716e7a3503997151e4780566f007313");
+
                             }
                         }
                     }
@@ -123,6 +138,12 @@ void FreeSound::slotShowResults(KJob* job)
 }
     
 
+/**
+ * @brief FreeSound::displayItemDetails
+ * @param item
+ * @return
+ * This is a slot
+ */
 OnlineItemInfo FreeSound::displayItemDetails(QListWidgetItem *item)
 {
     OnlineItemInfo info;
@@ -131,8 +152,7 @@ OnlineItemInfo FreeSound::displayItemDetails(QListWidgetItem *item)
         return info;
     }
     info.itemPreview = item->data(previewRole).toString();
-    info.itemDownload = item->data(downloadRole).toString();
-    info.itemId = item->data(idRole).toInt();
+    info.itemId = item->data(idRole).toString();
     info.itemName = item->text();
     info.infoUrl = item->data(infoUrl).toString();
     info.author = item->data(authorRole).toString();
@@ -142,18 +162,23 @@ OnlineItemInfo FreeSound::displayItemDetails(QListWidgetItem *item)
     info.description = item->data(descriptionRole).toString();
     
     QString extraInfoUrl = item->data(infoData).toString();
+
     if (!extraInfoUrl.isEmpty()) {
         KJob* resolveJob = KIO::storedGet( QUrl(extraInfoUrl), KIO::NoReload, KIO::HideProgressInfo );
+        // connect (obj,signal,obj, slot)
+        // when the KJob resolveJob emits a result signal slotParseResults will be notified
         connect(resolveJob, &KJob::result, this, &FreeSound::slotParseResults);
     }
-    emit gotThumb(item->data(imageRole).toString());
     return info;
 }
 
-
+/**
+ * @brief FreeSound::slotParseResults
+ * @param job
+ * emits gotMetaInfo which is connected to slotSetMetadata and to slotDisplayMetaInfo
+ */
 void FreeSound::slotParseResults(KJob* job)
 {
-#ifdef USE_QJSON
     KIO::StoredTransferJob* storedQueryJob = static_cast<KIO::StoredTransferJob*>( job );
     QJsonParseError jsonError;
     QJsonDocument doc = QJsonDocument::fromJson(storedQueryJob->data(), &jsonError);
@@ -163,16 +188,17 @@ void FreeSound::slotParseResults(KJob* job)
     }
     QVariant data = doc.toVariant();
     QString html = QString("<style type=\"text/css\">tr.cellone {background-color: %1;}</style>").arg(qApp->palette().alternateBase().color().name());
+
     if (data.canConvert(QVariant::Map)) {
         QMap <QString, QVariant> info = data.toMap();
-        //if (m_currentId != info.value("id").toInt()) return;
         
         html += "<table width=\"100%\" cellspacing=\"0\" cellpadding=\"2\">";
     
-        if (m_metaInfo.contains(i18n("Duration"))) {
+        if (info.contains("duration")) {
 	    html += "<tr>";
-            html += "<td>" + i18n("Duration") + "</td><td>" + m_metaInfo.value(i18n("Duration")) + "</td></tr>";
+            html += "<td>" + i18n("Duration") + "</td><td>" + QString::number( info.value("duration").toDouble()) + "</td></tr>";
             m_metaInfo.remove(i18n("Duration"));
+            m_metaInfo.insert(i18n("Duration"),  info.value("duration").toString());
         }
         
         if (info.contains("samplerate")) {
@@ -195,39 +221,67 @@ void FreeSound::slotParseResults(KJob* job)
         if (info.contains("description")) {
             m_metaInfo.insert("description", info.value("description").toString());
         }
+        if (info.contains("previews")) {
+            QMap <QString, QVariant> previews = info.value("previews").toMap();
+
+
+            if (previews.contains("preview-lq-mp3")) {
+                m_metaInfo.insert("itemPreview", previews.value("preview-lq-mp3").toString());
+            }
+            if (previews.contains("preview-hq-mp3")) {// use the high qual preview as the download file as a test temporality
+               m_metaInfo.insert("itemDownload", previews.value("preview-hq-mp3").toString());
+            }
+        }
+        if (info.contains("images")) {
+            QMap <QString, QVariant> images = info.value("images").toMap();
+
+
+            if (images.contains("waveform_m")) {
+                m_metaInfo.insert("itemImage", images.value("waveform_m").toString());
+            }
+        }
     }
+    html +="<p>Using v2 of freesound API. Import gets high quality .mp3 preview file at the moment";
     emit gotMetaInfo(html);
     emit gotMetaInfo(m_metaInfo);
-#else
-	Q_UNUSED(job)
-#endif    
+    emit gotThumb( m_metaInfo.value("itemImage"));
 }
 
-
+/**
+ * @brief FreeSound::startItemPreview
+ * @param item
+ * @return
+ */
 bool FreeSound::startItemPreview(QListWidgetItem *item)
-{    
+{
     if (!item)
         return false;
-    const QString url = item->data(previewRole).toString();
+    const QString url = m_metaInfo.value("itemPreview");
     if (url.isEmpty())
         return false;
     if (m_previewProcess) {
 	    if (m_previewProcess->state() != QProcess::NotRunning) {
 		    m_previewProcess->close();
 		}
-		m_previewProcess->start(KdenliveSettings::ffplaypath(), QStringList() << url << "-nodisp");
+        m_previewProcess->start(KdenliveSettings::ffplaypath(), QStringList() <<url<<"-nodisp"<<"-autoexit");
 	}
     return true;
 }
 
-
+/**
+ * @brief FreeSound::stopItemPreview
+ */
 void FreeSound::stopItemPreview(QListWidgetItem * /*item*/)
 {    
     if (m_previewProcess && m_previewProcess->state() != QProcess::NotRunning) {
         m_previewProcess->close();
     }
 }
-
+/**
+ * @brief FreeSound::getExtension
+ * @param item
+ * @return
+ */
 QString FreeSound::getExtension(QListWidgetItem *item)
 {
     if (!item)
@@ -235,7 +289,11 @@ QString FreeSound::getExtension(QListWidgetItem *item)
     return QString("*.") + item->text().section('.', -1);
 }
 
-
+/**
+ * @brief FreeSound::getDefaultDownloadName
+ * @param item
+ * @return
+ */
 QString FreeSound::getDefaultDownloadName(QListWidgetItem *item)
 {
     if (!item)
@@ -243,4 +301,15 @@ QString FreeSound::getDefaultDownloadName(QListWidgetItem *item)
     return item->text();
 }
 
-
+/**
+ * @brief FreeSound::slotPreviewFinished
+ * @param exitCode
+ * @param exitStatus
+ * Connected to the QProcess m_previewProcess finished signal
+ * emits signal picked up by ResourceWidget that ResouceWidget uses
+ * to set the Preview button back to the text Preview (it will say "Stop" before this.
+ */
+void FreeSound::slotPreviewFinished(int exitCode, QProcess::ExitStatus exitStatus)
+{
+     emit previewFinished();
+}
